#include <cstdint>

extern const uint64_t abs_f16_len;
extern const unsigned char abs_f16_data[];

extern const uint64_t abs_f32_len;
extern const unsigned char abs_f32_data[];

extern const uint64_t acc_f32_len;
extern const unsigned char acc_f32_data[];

extern const uint64_t add1_f16_f16_len;
extern const unsigned char add1_f16_f16_data[];

extern const uint64_t add1_f16_f32_len;
extern const unsigned char add1_f16_f32_data[];

extern const uint64_t add1_f32_f32_len;
extern const unsigned char add1_f32_f32_data[];

extern const uint64_t add_f16_f16_f16_len;
extern const unsigned char add_f16_f16_f16_data[];

extern const uint64_t add_f16_f16_f32_len;
extern const unsigned char add_f16_f16_f32_data[];

extern const uint64_t add_f16_f32_f16_len;
extern const unsigned char add_f16_f32_f16_data[];

extern const uint64_t add_f16_f32_f32_len;
extern const unsigned char add_f16_f32_f32_data[];

extern const uint64_t add_f32_f16_f16_len;
extern const unsigned char add_f32_f16_f16_data[];

extern const uint64_t add_f32_f16_f32_len;
extern const unsigned char add_f32_f16_f32_data[];

extern const uint64_t add_f32_f32_f16_len;
extern const unsigned char add_f32_f32_f16_data[];

extern const uint64_t add_f32_f32_f32_len;
extern const unsigned char add_f32_f32_f32_data[];

extern const uint64_t add_id_f32_len;
extern const unsigned char add_id_f32_data[];

extern const uint64_t add_rms_f16_f16_f16_len;
extern const unsigned char add_rms_f16_f16_f16_data[];

extern const uint64_t add_rms_f16_f16_f32_len;
extern const unsigned char add_rms_f16_f16_f32_data[];

extern const uint64_t add_rms_f16_f32_f16_len;
extern const unsigned char add_rms_f16_f32_f16_data[];

extern const uint64_t add_rms_f16_f32_f32_len;
extern const unsigned char add_rms_f16_f32_f32_data[];

extern const uint64_t add_rms_f32_f16_f16_len;
extern const unsigned char add_rms_f32_f16_f16_data[];

extern const uint64_t add_rms_f32_f16_f32_len;
extern const unsigned char add_rms_f32_f16_f32_data[];

extern const uint64_t add_rms_f32_f32_f16_len;
extern const unsigned char add_rms_f32_f32_f16_data[];

extern const uint64_t add_rms_f32_f32_f32_len;
extern const unsigned char add_rms_f32_f32_f32_data[];

extern const uint64_t arange_f32_len;
extern const unsigned char arange_f32_data[];

extern const uint64_t argmax_f32_len;
extern const unsigned char argmax_f32_data[];

extern const uint64_t argsort_f32_len;
extern const unsigned char argsort_f32_data[];

extern const uint64_t argsort_large_f32_len;
extern const unsigned char argsort_large_f32_data[];

extern const uint64_t ceil_f16_len;
extern const unsigned char ceil_f16_data[];

extern const uint64_t ceil_f32_len;
extern const unsigned char ceil_f32_data[];

extern const uint64_t clamp_f16_len;
extern const unsigned char clamp_f16_data[];

extern const uint64_t clamp_f32_len;
extern const unsigned char clamp_f32_data[];

extern const uint64_t col2im_1d_bf16_len;
extern const unsigned char col2im_1d_bf16_data[];

extern const uint64_t col2im_1d_f16_len;
extern const unsigned char col2im_1d_f16_data[];

extern const uint64_t col2im_1d_f32_len;
extern const unsigned char col2im_1d_f32_data[];

extern const uint64_t concat_i16_len;
extern const unsigned char concat_i16_data[];

extern const uint64_t concat_i32_len;
extern const unsigned char concat_i32_data[];

extern const uint64_t concat_i64_len;
extern const unsigned char concat_i64_data[];

extern const uint64_t concat_i8_len;
extern const unsigned char concat_i8_data[];

extern const uint64_t contig_cpy_bf16_f32_len;
extern const unsigned char contig_cpy_bf16_f32_data[];

extern const uint64_t contig_cpy_f16_f16_len;
extern const unsigned char contig_cpy_f16_f16_data[];

extern const uint64_t contig_cpy_f16_f32_len;
extern const unsigned char contig_cpy_f16_f32_data[];

extern const uint64_t contig_cpy_f32_bf16_len;
extern const unsigned char contig_cpy_f32_bf16_data[];

extern const uint64_t contig_cpy_f32_f16_len;
extern const unsigned char contig_cpy_f32_f16_data[];

extern const uint64_t contig_cpy_f32_f32_len;
extern const unsigned char contig_cpy_f32_f32_data[];

extern const uint64_t contig_cpy_f32_i32_len;
extern const unsigned char contig_cpy_f32_i32_data[];

extern const uint64_t contig_cpy_i32_f32_len;
extern const unsigned char contig_cpy_i32_f32_data[];

extern const uint64_t conv2d_dw_cwhn_f16_f32_len;
extern const unsigned char conv2d_dw_cwhn_f16_f32_data[];

extern const uint64_t conv2d_dw_cwhn_f32_len;
extern const unsigned char conv2d_dw_cwhn_f32_data[];

extern const uint64_t conv2d_dw_whcn_f16_f32_len;
extern const unsigned char conv2d_dw_whcn_f16_f32_data[];

extern const uint64_t conv2d_dw_whcn_f32_len;
extern const unsigned char conv2d_dw_whcn_f32_data[];

extern const uint64_t conv2d_f16_f32_len;
extern const unsigned char conv2d_f16_f32_data[];

extern const uint64_t conv2d_f16_f32_cm1_len;
extern const unsigned char conv2d_f16_f32_cm1_data[];

extern const uint64_t conv2d_f16_f32_cm2_len;
extern const unsigned char conv2d_f16_f32_cm2_data[];

extern const uint64_t conv2d_f16_f32_unroll_len;
extern const unsigned char conv2d_f16_f32_unroll_data[];

extern const uint64_t conv2d_f32_len;
extern const unsigned char conv2d_f32_data[];

extern const uint64_t conv2d_f32_cm1_len;
extern const unsigned char conv2d_f32_cm1_data[];

extern const uint64_t conv2d_f32_cm2_len;
extern const unsigned char conv2d_f32_cm2_data[];

extern const uint64_t conv2d_f32_unroll_len;
extern const unsigned char conv2d_f32_unroll_data[];

extern const uint64_t conv3d_f16_f32_len;
extern const unsigned char conv3d_f16_f32_data[];

extern const uint64_t conv3d_f16_f32_cm1_len;
extern const unsigned char conv3d_f16_f32_cm1_data[];

extern const uint64_t conv3d_f16_f32_cm2_len;
extern const unsigned char conv3d_f16_f32_cm2_data[];

extern const uint64_t conv3d_f16_f32_unroll_len;
extern const unsigned char conv3d_f16_f32_unroll_data[];

extern const uint64_t conv3d_f32_len;
extern const unsigned char conv3d_f32_data[];

extern const uint64_t conv3d_f32_cm1_len;
extern const unsigned char conv3d_f32_cm1_data[];

extern const uint64_t conv3d_f32_cm2_len;
extern const unsigned char conv3d_f32_cm2_data[];

extern const uint64_t conv3d_f32_unroll_len;
extern const unsigned char conv3d_f32_unroll_data[];

extern const uint64_t conv_transpose_1d_f32_len;
extern const unsigned char conv_transpose_1d_f32_data[];

extern const uint64_t conv_transpose_2d_f16_f32_len;
extern const unsigned char conv_transpose_2d_f16_f32_data[];

extern const uint64_t conv_transpose_2d_f16_f32_cm1_len;
extern const unsigned char conv_transpose_2d_f16_f32_cm1_data[];

extern const uint64_t conv_transpose_2d_f16_f32_cm2_len;
extern const unsigned char conv_transpose_2d_f16_f32_cm2_data[];

extern const uint64_t conv_transpose_2d_f16_f32_unroll_len;
extern const unsigned char conv_transpose_2d_f16_f32_unroll_data[];

extern const uint64_t conv_transpose_2d_f32_len;
extern const unsigned char conv_transpose_2d_f32_data[];

extern const uint64_t conv_transpose_2d_f32_cm1_len;
extern const unsigned char conv_transpose_2d_f32_cm1_data[];

extern const uint64_t conv_transpose_2d_f32_cm2_len;
extern const unsigned char conv_transpose_2d_f32_cm2_data[];

extern const uint64_t conv_transpose_2d_f32_unroll_len;
extern const unsigned char conv_transpose_2d_f32_unroll_data[];

extern const uint64_t cos_f16_len;
extern const unsigned char cos_f16_data[];

extern const uint64_t cos_f32_len;
extern const unsigned char cos_f32_data[];

extern const uint64_t count_equal_i32_len;
extern const unsigned char count_equal_i32_data[];

extern const uint64_t count_experts_len;
extern const unsigned char count_experts_data[];

extern const uint64_t cpy_bf16_f32_len;
extern const unsigned char cpy_bf16_f32_data[];

extern const uint64_t cpy_f16_f16_len;
extern const unsigned char cpy_f16_f16_data[];

extern const uint64_t cpy_f16_f32_len;
extern const unsigned char cpy_f16_f32_data[];

extern const uint64_t cpy_f32_bf16_len;
extern const unsigned char cpy_f32_bf16_data[];

extern const uint64_t cpy_f32_f16_len;
extern const unsigned char cpy_f32_f16_data[];

extern const uint64_t cpy_f32_f32_len;
extern const unsigned char cpy_f32_f32_data[];

extern const uint64_t cpy_f32_i32_len;
extern const unsigned char cpy_f32_i32_data[];

extern const uint64_t cpy_f32_iq4_nl_len;
extern const unsigned char cpy_f32_iq4_nl_data[];

extern const uint64_t cpy_f32_q1_0_len;
extern const unsigned char cpy_f32_q1_0_data[];

extern const uint64_t cpy_f32_q4_0_len;
extern const unsigned char cpy_f32_q4_0_data[];

extern const uint64_t cpy_f32_q4_1_len;
extern const unsigned char cpy_f32_q4_1_data[];

extern const uint64_t cpy_f32_q5_0_len;
extern const unsigned char cpy_f32_q5_0_data[];

extern const uint64_t cpy_f32_q5_1_len;
extern const unsigned char cpy_f32_q5_1_data[];

extern const uint64_t cpy_f32_q8_0_len;
extern const unsigned char cpy_f32_q8_0_data[];

extern const uint64_t cpy_i32_f32_len;
extern const unsigned char cpy_i32_f32_data[];

extern const uint64_t cpy_iq4_nl_f32_len;
extern const unsigned char cpy_iq4_nl_f32_data[];

extern const uint64_t cpy_q1_0_f32_len;
extern const unsigned char cpy_q1_0_f32_data[];

extern const uint64_t cpy_q4_0_f32_len;
extern const unsigned char cpy_q4_0_f32_data[];

extern const uint64_t cpy_q4_1_f32_len;
extern const unsigned char cpy_q4_1_f32_data[];

extern const uint64_t cpy_q5_0_f32_len;
extern const unsigned char cpy_q5_0_f32_data[];

extern const uint64_t cpy_q5_1_f32_len;
extern const unsigned char cpy_q5_1_f32_data[];

extern const uint64_t cpy_q8_0_f32_len;
extern const unsigned char cpy_q8_0_f32_data[];

extern const uint64_t cpy_transpose_16_len;
extern const unsigned char cpy_transpose_16_data[];

extern const uint64_t cpy_transpose_32_len;
extern const unsigned char cpy_transpose_32_data[];

extern const uint64_t cumsum_f32_len;
extern const unsigned char cumsum_f32_data[];

extern const uint64_t cumsum_multipass1_f32_len;
extern const unsigned char cumsum_multipass1_f32_data[];

extern const uint64_t cumsum_multipass2_f32_len;
extern const unsigned char cumsum_multipass2_f32_data[];

extern const uint64_t dequant_f32_len;
extern const unsigned char dequant_f32_data[];

extern const uint64_t dequant_iq1_m_len;
extern const unsigned char dequant_iq1_m_data[];

extern const uint64_t dequant_iq1_s_len;
extern const unsigned char dequant_iq1_s_data[];

extern const uint64_t dequant_iq2_s_len;
extern const unsigned char dequant_iq2_s_data[];

extern const uint64_t dequant_iq2_xs_len;
extern const unsigned char dequant_iq2_xs_data[];

extern const uint64_t dequant_iq2_xxs_len;
extern const unsigned char dequant_iq2_xxs_data[];

extern const uint64_t dequant_iq3_s_len;
extern const unsigned char dequant_iq3_s_data[];

extern const uint64_t dequant_iq3_xxs_len;
extern const unsigned char dequant_iq3_xxs_data[];

extern const uint64_t dequant_iq4_nl_len;
extern const unsigned char dequant_iq4_nl_data[];

extern const uint64_t dequant_iq4_xs_len;
extern const unsigned char dequant_iq4_xs_data[];

extern const uint64_t dequant_mxfp4_len;
extern const unsigned char dequant_mxfp4_data[];

extern const uint64_t dequant_nvfp4_len;
extern const unsigned char dequant_nvfp4_data[];

extern const uint64_t dequant_q1_0_len;
extern const unsigned char dequant_q1_0_data[];

extern const uint64_t dequant_q2_k_len;
extern const unsigned char dequant_q2_k_data[];

extern const uint64_t dequant_q3_k_len;
extern const unsigned char dequant_q3_k_data[];

extern const uint64_t dequant_q4_0_len;
extern const unsigned char dequant_q4_0_data[];

extern const uint64_t dequant_q4_1_len;
extern const unsigned char dequant_q4_1_data[];

extern const uint64_t dequant_q4_k_len;
extern const unsigned char dequant_q4_k_data[];

extern const uint64_t dequant_q5_0_len;
extern const unsigned char dequant_q5_0_data[];

extern const uint64_t dequant_q5_1_len;
extern const unsigned char dequant_q5_1_data[];

extern const uint64_t dequant_q5_k_len;
extern const unsigned char dequant_q5_k_data[];

extern const uint64_t dequant_q6_k_len;
extern const unsigned char dequant_q6_k_data[];

extern const uint64_t dequant_q8_0_len;
extern const unsigned char dequant_q8_0_data[];

extern const uint64_t diag_f16_len;
extern const unsigned char diag_f16_data[];

extern const uint64_t diag_f32_len;
extern const unsigned char diag_f32_data[];

extern const uint64_t diag_mask_inf_f32_len;
extern const unsigned char diag_mask_inf_f32_data[];

extern const uint64_t div_f16_f16_f16_len;
extern const unsigned char div_f16_f16_f16_data[];

extern const uint64_t div_f16_f16_f32_len;
extern const unsigned char div_f16_f16_f32_data[];

extern const uint64_t div_f16_f32_f16_len;
extern const unsigned char div_f16_f32_f16_data[];

extern const uint64_t div_f16_f32_f32_len;
extern const unsigned char div_f16_f32_f32_data[];

extern const uint64_t div_f32_len;
extern const unsigned char div_f32_data[];

extern const uint64_t div_f32_f16_f16_len;
extern const unsigned char div_f32_f16_f16_data[];

extern const uint64_t div_f32_f16_f32_len;
extern const unsigned char div_f32_f16_f32_data[];

extern const uint64_t div_f32_f32_f16_len;
extern const unsigned char div_f32_f32_f16_data[];

extern const uint64_t div_f32_f32_f32_len;
extern const unsigned char div_f32_f32_f32_data[];

extern const uint64_t elu_f16_len;
extern const unsigned char elu_f16_data[];

extern const uint64_t elu_f32_len;
extern const unsigned char elu_f32_data[];

extern const uint64_t exp_f16_len;
extern const unsigned char exp_f16_data[];

extern const uint64_t exp_f32_len;
extern const unsigned char exp_f32_data[];

extern const uint64_t expm1_f16_len;
extern const unsigned char expm1_f16_data[];

extern const uint64_t expm1_f32_len;
extern const unsigned char expm1_f32_data[];

extern const uint64_t fa_mask_opt_len;
extern const unsigned char fa_mask_opt_data[];

extern const uint64_t fa_split_k_reduce_len;
extern const unsigned char fa_split_k_reduce_data[];

extern const uint64_t fill_f16_len;
extern const unsigned char fill_f16_data[];

extern const uint64_t fill_f32_len;
extern const unsigned char fill_f32_data[];

extern const uint64_t flash_attn_f32_f16_len;
extern const unsigned char flash_attn_f32_f16_data[];

extern const uint64_t flash_attn_f32_f16_bf16_cm1_len;
extern const unsigned char flash_attn_f32_f16_bf16_cm1_data[];

extern const uint64_t flash_attn_f32_f16_bf16_cm2_len;
extern const unsigned char flash_attn_f32_f16_bf16_cm2_data[];

extern const uint64_t flash_attn_f32_f16_cm1_len;
extern const unsigned char flash_attn_f32_f16_cm1_data[];

extern const uint64_t flash_attn_f32_f16_cm2_len;
extern const unsigned char flash_attn_f32_f16_cm2_data[];

extern const uint64_t flash_attn_f32_f16_dot2_len;
extern const unsigned char flash_attn_f32_f16_dot2_data[];

extern const uint64_t flash_attn_f32_f16_dot2_f16acc_len;
extern const unsigned char flash_attn_f32_f16_dot2_f16acc_data[];

extern const uint64_t flash_attn_f32_f16_f16acc_len;
extern const unsigned char flash_attn_f32_f16_f16acc_data[];

extern const uint64_t flash_attn_f32_f16_f16acc_cm1_len;
extern const unsigned char flash_attn_f32_f16_f16acc_cm1_data[];

extern const uint64_t flash_attn_f32_f16_f16acc_cm2_len;
extern const unsigned char flash_attn_f32_f16_f16acc_cm2_data[];

extern const uint64_t flash_attn_f32_f16_f16acc_fp32_len;
extern const unsigned char flash_attn_f32_f16_f16acc_fp32_data[];

extern const uint64_t flash_attn_f32_f16_f16acc_fp32_int8_len;
extern const unsigned char flash_attn_f32_f16_f16acc_fp32_int8_data[];

extern const uint64_t flash_attn_f32_f16_f16acc_int8_len;
extern const unsigned char flash_attn_f32_f16_f16acc_int8_data[];

extern const uint64_t flash_attn_f32_f16_fp32_len;
extern const unsigned char flash_attn_f32_f16_fp32_data[];

extern const uint64_t flash_attn_f32_f16_fp32_int8_len;
extern const unsigned char flash_attn_f32_f16_fp32_int8_data[];

extern const uint64_t flash_attn_f32_f16_int8_len;
extern const unsigned char flash_attn_f32_f16_int8_data[];

extern const uint64_t floor_f16_len;
extern const unsigned char floor_f16_data[];

extern const uint64_t floor_f32_len;
extern const unsigned char floor_f32_data[];

extern const uint64_t fwht_f32_len;
extern const unsigned char fwht_f32_data[];

extern const uint64_t fwht_shmem_f32_len;
extern const unsigned char fwht_shmem_f32_data[];

extern const uint64_t gated_delta_net_f32_len;
extern const unsigned char gated_delta_net_f32_data[];

extern const uint64_t gated_delta_net_f32_nocluster_len;
extern const unsigned char gated_delta_net_f32_nocluster_data[];

extern const uint64_t gated_delta_net_f32_shmem_len;
extern const unsigned char gated_delta_net_f32_shmem_data[];

extern const uint64_t geglu_erf_f16_len;
extern const unsigned char geglu_erf_f16_data[];

extern const uint64_t geglu_erf_f32_len;
extern const unsigned char geglu_erf_f32_data[];

extern const uint64_t geglu_f16_len;
extern const unsigned char geglu_f16_data[];

extern const uint64_t geglu_f32_len;
extern const unsigned char geglu_f32_data[];

extern const uint64_t geglu_quick_f16_len;
extern const unsigned char geglu_quick_f16_data[];

extern const uint64_t geglu_quick_f32_len;
extern const unsigned char geglu_quick_f32_data[];

extern const uint64_t gelu_erf_f16_len;
extern const unsigned char gelu_erf_f16_data[];

extern const uint64_t gelu_erf_f32_len;
extern const unsigned char gelu_erf_f32_data[];

extern const uint64_t gelu_f16_len;
extern const unsigned char gelu_f16_data[];

extern const uint64_t gelu_f32_len;
extern const unsigned char gelu_f32_data[];

extern const uint64_t gelu_quick_f16_len;
extern const unsigned char gelu_quick_f16_data[];

extern const uint64_t gelu_quick_f32_len;
extern const unsigned char gelu_quick_f32_data[];

extern const uint64_t get_rows_back_f32_len;
extern const unsigned char get_rows_back_f32_data[];

extern const uint64_t get_rows_bf16_len;
extern const unsigned char get_rows_bf16_data[];

extern const uint64_t get_rows_bf16_f32_len;
extern const unsigned char get_rows_bf16_f32_data[];

extern const uint64_t get_rows_f16_len;
extern const unsigned char get_rows_f16_data[];

extern const uint64_t get_rows_f16_f32_len;
extern const unsigned char get_rows_f16_f32_data[];

extern const uint64_t get_rows_f32_len;
extern const unsigned char get_rows_f32_data[];

extern const uint64_t get_rows_f32_f32_len;
extern const unsigned char get_rows_f32_f32_data[];

extern const uint64_t get_rows_i32_len;
extern const unsigned char get_rows_i32_data[];

extern const uint64_t get_rows_iq1_m_len;
extern const unsigned char get_rows_iq1_m_data[];

extern const uint64_t get_rows_iq1_m_f32_len;
extern const unsigned char get_rows_iq1_m_f32_data[];

extern const uint64_t get_rows_iq1_s_len;
extern const unsigned char get_rows_iq1_s_data[];

extern const uint64_t get_rows_iq1_s_f32_len;
extern const unsigned char get_rows_iq1_s_f32_data[];

extern const uint64_t get_rows_iq2_s_len;
extern const unsigned char get_rows_iq2_s_data[];

extern const uint64_t get_rows_iq2_s_f32_len;
extern const unsigned char get_rows_iq2_s_f32_data[];

extern const uint64_t get_rows_iq2_xs_len;
extern const unsigned char get_rows_iq2_xs_data[];

extern const uint64_t get_rows_iq2_xs_f32_len;
extern const unsigned char get_rows_iq2_xs_f32_data[];

extern const uint64_t get_rows_iq2_xxs_len;
extern const unsigned char get_rows_iq2_xxs_data[];

extern const uint64_t get_rows_iq2_xxs_f32_len;
extern const unsigned char get_rows_iq2_xxs_f32_data[];

extern const uint64_t get_rows_iq3_s_len;
extern const unsigned char get_rows_iq3_s_data[];

extern const uint64_t get_rows_iq3_s_f32_len;
extern const unsigned char get_rows_iq3_s_f32_data[];

extern const uint64_t get_rows_iq3_xxs_len;
extern const unsigned char get_rows_iq3_xxs_data[];

extern const uint64_t get_rows_iq3_xxs_f32_len;
extern const unsigned char get_rows_iq3_xxs_f32_data[];

extern const uint64_t get_rows_iq4_nl_len;
extern const unsigned char get_rows_iq4_nl_data[];

extern const uint64_t get_rows_iq4_nl_f32_len;
extern const unsigned char get_rows_iq4_nl_f32_data[];

extern const uint64_t get_rows_iq4_xs_len;
extern const unsigned char get_rows_iq4_xs_data[];

extern const uint64_t get_rows_iq4_xs_f32_len;
extern const unsigned char get_rows_iq4_xs_f32_data[];

extern const uint64_t get_rows_mxfp4_len;
extern const unsigned char get_rows_mxfp4_data[];

extern const uint64_t get_rows_mxfp4_f32_len;
extern const unsigned char get_rows_mxfp4_f32_data[];

extern const uint64_t get_rows_nvfp4_len;
extern const unsigned char get_rows_nvfp4_data[];

extern const uint64_t get_rows_nvfp4_f32_len;
extern const unsigned char get_rows_nvfp4_f32_data[];

extern const uint64_t get_rows_q1_0_len;
extern const unsigned char get_rows_q1_0_data[];

extern const uint64_t get_rows_q1_0_f32_len;
extern const unsigned char get_rows_q1_0_f32_data[];

extern const uint64_t get_rows_q2_k_len;
extern const unsigned char get_rows_q2_k_data[];

extern const uint64_t get_rows_q2_k_f32_len;
extern const unsigned char get_rows_q2_k_f32_data[];

extern const uint64_t get_rows_q3_k_len;
extern const unsigned char get_rows_q3_k_data[];

extern const uint64_t get_rows_q3_k_f32_len;
extern const unsigned char get_rows_q3_k_f32_data[];

extern const uint64_t get_rows_q4_0_len;
extern const unsigned char get_rows_q4_0_data[];

extern const uint64_t get_rows_q4_0_f32_len;
extern const unsigned char get_rows_q4_0_f32_data[];

extern const uint64_t get_rows_q4_1_len;
extern const unsigned char get_rows_q4_1_data[];

extern const uint64_t get_rows_q4_1_f32_len;
extern const unsigned char get_rows_q4_1_f32_data[];

extern const uint64_t get_rows_q4_k_len;
extern const unsigned char get_rows_q4_k_data[];

extern const uint64_t get_rows_q4_k_f32_len;
extern const unsigned char get_rows_q4_k_f32_data[];

extern const uint64_t get_rows_q5_0_len;
extern const unsigned char get_rows_q5_0_data[];

extern const uint64_t get_rows_q5_0_f32_len;
extern const unsigned char get_rows_q5_0_f32_data[];

extern const uint64_t get_rows_q5_1_len;
extern const unsigned char get_rows_q5_1_data[];

extern const uint64_t get_rows_q5_1_f32_len;
extern const unsigned char get_rows_q5_1_f32_data[];

extern const uint64_t get_rows_q5_k_len;
extern const unsigned char get_rows_q5_k_data[];

extern const uint64_t get_rows_q5_k_f32_len;
extern const unsigned char get_rows_q5_k_f32_data[];

extern const uint64_t get_rows_q6_k_len;
extern const unsigned char get_rows_q6_k_data[];

extern const uint64_t get_rows_q6_k_f32_len;
extern const unsigned char get_rows_q6_k_f32_data[];

extern const uint64_t get_rows_q8_0_len;
extern const unsigned char get_rows_q8_0_data[];

extern const uint64_t get_rows_q8_0_f32_len;
extern const unsigned char get_rows_q8_0_f32_data[];

extern const uint64_t group_norm_f32_len;
extern const unsigned char group_norm_f32_data[];

extern const uint64_t hardsigmoid_f16_len;
extern const unsigned char hardsigmoid_f16_data[];

extern const uint64_t hardsigmoid_f32_len;
extern const unsigned char hardsigmoid_f32_data[];

extern const uint64_t hardswish_f16_len;
extern const unsigned char hardswish_f16_data[];

extern const uint64_t hardswish_f32_len;
extern const unsigned char hardswish_f32_data[];

extern const uint64_t im2col_3d_f32_len;
extern const unsigned char im2col_3d_f32_data[];

extern const uint64_t im2col_3d_f32_bda_len;
extern const unsigned char im2col_3d_f32_bda_data[];

extern const uint64_t im2col_3d_f32_f16_len;
extern const unsigned char im2col_3d_f32_f16_data[];

extern const uint64_t im2col_3d_f32_f16_bda_len;
extern const unsigned char im2col_3d_f32_f16_bda_data[];

extern const uint64_t im2col_f32_len;
extern const unsigned char im2col_f32_data[];

extern const uint64_t im2col_f32_bda_len;
extern const unsigned char im2col_f32_bda_data[];

extern const uint64_t im2col_f32_f16_len;
extern const unsigned char im2col_f32_f16_data[];

extern const uint64_t im2col_f32_f16_bda_len;
extern const unsigned char im2col_f32_f16_bda_data[];

extern const uint64_t l2_norm_f32_len;
extern const unsigned char l2_norm_f32_data[];

extern const uint64_t leaky_relu_f16_len;
extern const unsigned char leaky_relu_f16_data[];

extern const uint64_t leaky_relu_f32_len;
extern const unsigned char leaky_relu_f32_data[];

extern const uint64_t log_f16_len;
extern const unsigned char log_f16_data[];

extern const uint64_t log_f32_len;
extern const unsigned char log_f32_data[];

extern const uint64_t matmul_bf16_len;
extern const unsigned char matmul_bf16_data[];

extern const uint64_t matmul_bf16_cm1_len;
extern const unsigned char matmul_bf16_cm1_data[];

extern const uint64_t matmul_bf16_cm2_len;
extern const unsigned char matmul_bf16_cm2_data[];

extern const uint64_t matmul_bf16_f16acc_len;
extern const unsigned char matmul_bf16_f16acc_data[];

extern const uint64_t matmul_bf16_f16acc_cm1_len;
extern const unsigned char matmul_bf16_f16acc_cm1_data[];

extern const uint64_t matmul_bf16_f16acc_cm2_len;
extern const unsigned char matmul_bf16_f16acc_cm2_data[];

extern const uint64_t matmul_bf16_fp32_len;
extern const unsigned char matmul_bf16_fp32_data[];

extern const uint64_t matmul_f16_len;
extern const unsigned char matmul_f16_data[];

extern const uint64_t matmul_f16_cm1_len;
extern const unsigned char matmul_f16_cm1_data[];

extern const uint64_t matmul_f16_cm2_len;
extern const unsigned char matmul_f16_cm2_data[];

extern const uint64_t matmul_f16_dot2_len;
extern const unsigned char matmul_f16_dot2_data[];

extern const uint64_t matmul_f16_dot2_f16acc_len;
extern const unsigned char matmul_f16_dot2_f16acc_data[];

extern const uint64_t matmul_f16_f16acc_len;
extern const unsigned char matmul_f16_f16acc_data[];

extern const uint64_t matmul_f16_f16acc_cm1_len;
extern const unsigned char matmul_f16_f16acc_cm1_data[];

extern const uint64_t matmul_f16_f16acc_cm2_len;
extern const unsigned char matmul_f16_f16acc_cm2_data[];

extern const uint64_t matmul_f16_f32_len;
extern const unsigned char matmul_f16_f32_data[];

extern const uint64_t matmul_f16_f32_cm1_len;
extern const unsigned char matmul_f16_f32_cm1_data[];

extern const uint64_t matmul_f16_f32_dot2_len;
extern const unsigned char matmul_f16_f32_dot2_data[];

extern const uint64_t matmul_f16_f32_dot2_f16acc_len;
extern const unsigned char matmul_f16_f32_dot2_f16acc_data[];

extern const uint64_t matmul_f16_f32_f16acc_len;
extern const unsigned char matmul_f16_f32_f16acc_data[];

extern const uint64_t matmul_f16_f32_f16acc_cm1_len;
extern const unsigned char matmul_f16_f32_f16acc_cm1_data[];

extern const uint64_t matmul_f16_f32_fp32_len;
extern const unsigned char matmul_f16_f32_fp32_data[];

extern const uint64_t matmul_f16_fp32_len;
extern const unsigned char matmul_f16_fp32_data[];

extern const uint64_t matmul_f32_f16_len;
extern const unsigned char matmul_f32_f16_data[];

extern const uint64_t matmul_f32_f16_cm1_len;
extern const unsigned char matmul_f32_f16_cm1_data[];

extern const uint64_t matmul_f32_f16_cm2_len;
extern const unsigned char matmul_f32_f16_cm2_data[];

extern const uint64_t matmul_f32_f16_dot2_len;
extern const unsigned char matmul_f32_f16_dot2_data[];

extern const uint64_t matmul_f32_f16_dot2_f16acc_len;
extern const unsigned char matmul_f32_f16_dot2_f16acc_data[];

extern const uint64_t matmul_f32_f16_f16acc_len;
extern const unsigned char matmul_f32_f16_f16acc_data[];

extern const uint64_t matmul_f32_f16_f16acc_cm1_len;
extern const unsigned char matmul_f32_f16_f16acc_cm1_data[];

extern const uint64_t matmul_f32_f16_f16acc_cm2_len;
extern const unsigned char matmul_f32_f16_f16acc_cm2_data[];

extern const uint64_t matmul_f32_f16_fp32_len;
extern const unsigned char matmul_f32_f16_fp32_data[];

extern const uint64_t matmul_f32_f32_len;
extern const unsigned char matmul_f32_f32_data[];

extern const uint64_t matmul_f32_f32_cm1_len;
extern const unsigned char matmul_f32_f32_cm1_data[];

extern const uint64_t matmul_f32_f32_dot2_len;
extern const unsigned char matmul_f32_f32_dot2_data[];

extern const uint64_t matmul_f32_f32_dot2_f16acc_len;
extern const unsigned char matmul_f32_f32_dot2_f16acc_data[];

extern const uint64_t matmul_f32_f32_f16acc_len;
extern const unsigned char matmul_f32_f32_f16acc_data[];

extern const uint64_t matmul_f32_f32_f16acc_cm1_len;
extern const unsigned char matmul_f32_f32_f16acc_cm1_data[];

extern const uint64_t matmul_f32_f32_fp32_len;
extern const unsigned char matmul_f32_f32_fp32_data[];

extern const uint64_t matmul_id_bf16_len;
extern const unsigned char matmul_id_bf16_data[];

extern const uint64_t matmul_id_bf16_f16acc_len;
extern const unsigned char matmul_id_bf16_f16acc_data[];

extern const uint64_t matmul_id_bf16_fp32_len;
extern const unsigned char matmul_id_bf16_fp32_data[];

extern const uint64_t matmul_id_f16_len;
extern const unsigned char matmul_id_f16_data[];

extern const uint64_t matmul_id_f16_dot2_len;
extern const unsigned char matmul_id_f16_dot2_data[];

extern const uint64_t matmul_id_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_f16_f16acc_len;
extern const unsigned char matmul_id_f16_f16acc_data[];

extern const uint64_t matmul_id_f16_f32_len;
extern const unsigned char matmul_id_f16_f32_data[];

extern const uint64_t matmul_id_f16_f32_dot2_len;
extern const unsigned char matmul_id_f16_f32_dot2_data[];

extern const uint64_t matmul_id_f16_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_f16_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_f16_f32_f16acc_len;
extern const unsigned char matmul_id_f16_f32_f16acc_data[];

extern const uint64_t matmul_id_f16_f32_fp32_len;
extern const unsigned char matmul_id_f16_f32_fp32_data[];

extern const uint64_t matmul_id_f16_fp32_len;
extern const unsigned char matmul_id_f16_fp32_data[];

extern const uint64_t matmul_id_f32_f16_len;
extern const unsigned char matmul_id_f32_f16_data[];

extern const uint64_t matmul_id_f32_f16_dot2_len;
extern const unsigned char matmul_id_f32_f16_dot2_data[];

extern const uint64_t matmul_id_f32_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_f32_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_f32_f16_f16acc_len;
extern const unsigned char matmul_id_f32_f16_f16acc_data[];

extern const uint64_t matmul_id_f32_f16_fp32_len;
extern const unsigned char matmul_id_f32_f16_fp32_data[];

extern const uint64_t matmul_id_f32_f32_len;
extern const unsigned char matmul_id_f32_f32_data[];

extern const uint64_t matmul_id_f32_f32_dot2_len;
extern const unsigned char matmul_id_f32_f32_dot2_data[];

extern const uint64_t matmul_id_f32_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_f32_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_f32_f32_f16acc_len;
extern const unsigned char matmul_id_f32_f32_f16acc_data[];

extern const uint64_t matmul_id_f32_f32_fp32_len;
extern const unsigned char matmul_id_f32_f32_fp32_data[];

extern const uint64_t matmul_id_iq1_m_f16_len;
extern const unsigned char matmul_id_iq1_m_f16_data[];

extern const uint64_t matmul_id_iq1_m_f16_dot2_len;
extern const unsigned char matmul_id_iq1_m_f16_dot2_data[];

extern const uint64_t matmul_id_iq1_m_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_iq1_m_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq1_m_f16_f16acc_len;
extern const unsigned char matmul_id_iq1_m_f16_f16acc_data[];

extern const uint64_t matmul_id_iq1_m_f16_fp32_len;
extern const unsigned char matmul_id_iq1_m_f16_fp32_data[];

extern const uint64_t matmul_id_iq1_m_f32_len;
extern const unsigned char matmul_id_iq1_m_f32_data[];

extern const uint64_t matmul_id_iq1_m_f32_dot2_len;
extern const unsigned char matmul_id_iq1_m_f32_dot2_data[];

extern const uint64_t matmul_id_iq1_m_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_iq1_m_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq1_m_f32_f16acc_len;
extern const unsigned char matmul_id_iq1_m_f32_f16acc_data[];

extern const uint64_t matmul_id_iq1_m_f32_fp32_len;
extern const unsigned char matmul_id_iq1_m_f32_fp32_data[];

extern const uint64_t matmul_id_iq1_s_f16_len;
extern const unsigned char matmul_id_iq1_s_f16_data[];

extern const uint64_t matmul_id_iq1_s_f16_dot2_len;
extern const unsigned char matmul_id_iq1_s_f16_dot2_data[];

extern const uint64_t matmul_id_iq1_s_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_iq1_s_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq1_s_f16_f16acc_len;
extern const unsigned char matmul_id_iq1_s_f16_f16acc_data[];

extern const uint64_t matmul_id_iq1_s_f16_fp32_len;
extern const unsigned char matmul_id_iq1_s_f16_fp32_data[];

extern const uint64_t matmul_id_iq1_s_f32_len;
extern const unsigned char matmul_id_iq1_s_f32_data[];

extern const uint64_t matmul_id_iq1_s_f32_dot2_len;
extern const unsigned char matmul_id_iq1_s_f32_dot2_data[];

extern const uint64_t matmul_id_iq1_s_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_iq1_s_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq1_s_f32_f16acc_len;
extern const unsigned char matmul_id_iq1_s_f32_f16acc_data[];

extern const uint64_t matmul_id_iq1_s_f32_fp32_len;
extern const unsigned char matmul_id_iq1_s_f32_fp32_data[];

extern const uint64_t matmul_id_iq2_s_f16_len;
extern const unsigned char matmul_id_iq2_s_f16_data[];

extern const uint64_t matmul_id_iq2_s_f16_dot2_len;
extern const unsigned char matmul_id_iq2_s_f16_dot2_data[];

extern const uint64_t matmul_id_iq2_s_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_iq2_s_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq2_s_f16_f16acc_len;
extern const unsigned char matmul_id_iq2_s_f16_f16acc_data[];

extern const uint64_t matmul_id_iq2_s_f16_fp32_len;
extern const unsigned char matmul_id_iq2_s_f16_fp32_data[];

extern const uint64_t matmul_id_iq2_s_f32_len;
extern const unsigned char matmul_id_iq2_s_f32_data[];

extern const uint64_t matmul_id_iq2_s_f32_dot2_len;
extern const unsigned char matmul_id_iq2_s_f32_dot2_data[];

extern const uint64_t matmul_id_iq2_s_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_iq2_s_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq2_s_f32_f16acc_len;
extern const unsigned char matmul_id_iq2_s_f32_f16acc_data[];

extern const uint64_t matmul_id_iq2_s_f32_fp32_len;
extern const unsigned char matmul_id_iq2_s_f32_fp32_data[];

extern const uint64_t matmul_id_iq2_xs_f16_len;
extern const unsigned char matmul_id_iq2_xs_f16_data[];

extern const uint64_t matmul_id_iq2_xs_f16_dot2_len;
extern const unsigned char matmul_id_iq2_xs_f16_dot2_data[];

extern const uint64_t matmul_id_iq2_xs_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_iq2_xs_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq2_xs_f16_f16acc_len;
extern const unsigned char matmul_id_iq2_xs_f16_f16acc_data[];

extern const uint64_t matmul_id_iq2_xs_f16_fp32_len;
extern const unsigned char matmul_id_iq2_xs_f16_fp32_data[];

extern const uint64_t matmul_id_iq2_xs_f32_len;
extern const unsigned char matmul_id_iq2_xs_f32_data[];

extern const uint64_t matmul_id_iq2_xs_f32_dot2_len;
extern const unsigned char matmul_id_iq2_xs_f32_dot2_data[];

extern const uint64_t matmul_id_iq2_xs_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_iq2_xs_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq2_xs_f32_f16acc_len;
extern const unsigned char matmul_id_iq2_xs_f32_f16acc_data[];

extern const uint64_t matmul_id_iq2_xs_f32_fp32_len;
extern const unsigned char matmul_id_iq2_xs_f32_fp32_data[];

extern const uint64_t matmul_id_iq2_xxs_f16_len;
extern const unsigned char matmul_id_iq2_xxs_f16_data[];

extern const uint64_t matmul_id_iq2_xxs_f16_dot2_len;
extern const unsigned char matmul_id_iq2_xxs_f16_dot2_data[];

extern const uint64_t matmul_id_iq2_xxs_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_iq2_xxs_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq2_xxs_f16_f16acc_len;
extern const unsigned char matmul_id_iq2_xxs_f16_f16acc_data[];

extern const uint64_t matmul_id_iq2_xxs_f16_fp32_len;
extern const unsigned char matmul_id_iq2_xxs_f16_fp32_data[];

extern const uint64_t matmul_id_iq2_xxs_f32_len;
extern const unsigned char matmul_id_iq2_xxs_f32_data[];

extern const uint64_t matmul_id_iq2_xxs_f32_dot2_len;
extern const unsigned char matmul_id_iq2_xxs_f32_dot2_data[];

extern const uint64_t matmul_id_iq2_xxs_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_iq2_xxs_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq2_xxs_f32_f16acc_len;
extern const unsigned char matmul_id_iq2_xxs_f32_f16acc_data[];

extern const uint64_t matmul_id_iq2_xxs_f32_fp32_len;
extern const unsigned char matmul_id_iq2_xxs_f32_fp32_data[];

extern const uint64_t matmul_id_iq3_s_f16_len;
extern const unsigned char matmul_id_iq3_s_f16_data[];

extern const uint64_t matmul_id_iq3_s_f16_dot2_len;
extern const unsigned char matmul_id_iq3_s_f16_dot2_data[];

extern const uint64_t matmul_id_iq3_s_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_iq3_s_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq3_s_f16_f16acc_len;
extern const unsigned char matmul_id_iq3_s_f16_f16acc_data[];

extern const uint64_t matmul_id_iq3_s_f16_fp32_len;
extern const unsigned char matmul_id_iq3_s_f16_fp32_data[];

extern const uint64_t matmul_id_iq3_s_f32_len;
extern const unsigned char matmul_id_iq3_s_f32_data[];

extern const uint64_t matmul_id_iq3_s_f32_dot2_len;
extern const unsigned char matmul_id_iq3_s_f32_dot2_data[];

extern const uint64_t matmul_id_iq3_s_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_iq3_s_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq3_s_f32_f16acc_len;
extern const unsigned char matmul_id_iq3_s_f32_f16acc_data[];

extern const uint64_t matmul_id_iq3_s_f32_fp32_len;
extern const unsigned char matmul_id_iq3_s_f32_fp32_data[];

extern const uint64_t matmul_id_iq3_xxs_f16_len;
extern const unsigned char matmul_id_iq3_xxs_f16_data[];

extern const uint64_t matmul_id_iq3_xxs_f16_dot2_len;
extern const unsigned char matmul_id_iq3_xxs_f16_dot2_data[];

extern const uint64_t matmul_id_iq3_xxs_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_iq3_xxs_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq3_xxs_f16_f16acc_len;
extern const unsigned char matmul_id_iq3_xxs_f16_f16acc_data[];

extern const uint64_t matmul_id_iq3_xxs_f16_fp32_len;
extern const unsigned char matmul_id_iq3_xxs_f16_fp32_data[];

extern const uint64_t matmul_id_iq3_xxs_f32_len;
extern const unsigned char matmul_id_iq3_xxs_f32_data[];

extern const uint64_t matmul_id_iq3_xxs_f32_dot2_len;
extern const unsigned char matmul_id_iq3_xxs_f32_dot2_data[];

extern const uint64_t matmul_id_iq3_xxs_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_iq3_xxs_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq3_xxs_f32_f16acc_len;
extern const unsigned char matmul_id_iq3_xxs_f32_f16acc_data[];

extern const uint64_t matmul_id_iq3_xxs_f32_fp32_len;
extern const unsigned char matmul_id_iq3_xxs_f32_fp32_data[];

extern const uint64_t matmul_id_iq4_nl_f16_len;
extern const unsigned char matmul_id_iq4_nl_f16_data[];

extern const uint64_t matmul_id_iq4_nl_f16_dot2_len;
extern const unsigned char matmul_id_iq4_nl_f16_dot2_data[];

extern const uint64_t matmul_id_iq4_nl_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_iq4_nl_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq4_nl_f16_f16acc_len;
extern const unsigned char matmul_id_iq4_nl_f16_f16acc_data[];

extern const uint64_t matmul_id_iq4_nl_f16_fp32_len;
extern const unsigned char matmul_id_iq4_nl_f16_fp32_data[];

extern const uint64_t matmul_id_iq4_nl_f32_len;
extern const unsigned char matmul_id_iq4_nl_f32_data[];

extern const uint64_t matmul_id_iq4_nl_f32_dot2_len;
extern const unsigned char matmul_id_iq4_nl_f32_dot2_data[];

extern const uint64_t matmul_id_iq4_nl_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_iq4_nl_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq4_nl_f32_f16acc_len;
extern const unsigned char matmul_id_iq4_nl_f32_f16acc_data[];

extern const uint64_t matmul_id_iq4_nl_f32_fp32_len;
extern const unsigned char matmul_id_iq4_nl_f32_fp32_data[];

extern const uint64_t matmul_id_iq4_xs_f16_len;
extern const unsigned char matmul_id_iq4_xs_f16_data[];

extern const uint64_t matmul_id_iq4_xs_f16_dot2_len;
extern const unsigned char matmul_id_iq4_xs_f16_dot2_data[];

extern const uint64_t matmul_id_iq4_xs_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_iq4_xs_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq4_xs_f16_f16acc_len;
extern const unsigned char matmul_id_iq4_xs_f16_f16acc_data[];

extern const uint64_t matmul_id_iq4_xs_f16_fp32_len;
extern const unsigned char matmul_id_iq4_xs_f16_fp32_data[];

extern const uint64_t matmul_id_iq4_xs_f32_len;
extern const unsigned char matmul_id_iq4_xs_f32_data[];

extern const uint64_t matmul_id_iq4_xs_f32_dot2_len;
extern const unsigned char matmul_id_iq4_xs_f32_dot2_data[];

extern const uint64_t matmul_id_iq4_xs_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_iq4_xs_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_iq4_xs_f32_f16acc_len;
extern const unsigned char matmul_id_iq4_xs_f32_f16acc_data[];

extern const uint64_t matmul_id_iq4_xs_f32_fp32_len;
extern const unsigned char matmul_id_iq4_xs_f32_fp32_data[];

extern const uint64_t matmul_id_mxfp4_f16_len;
extern const unsigned char matmul_id_mxfp4_f16_data[];

extern const uint64_t matmul_id_mxfp4_f16_dot2_len;
extern const unsigned char matmul_id_mxfp4_f16_dot2_data[];

extern const uint64_t matmul_id_mxfp4_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_mxfp4_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_mxfp4_f16_f16acc_len;
extern const unsigned char matmul_id_mxfp4_f16_f16acc_data[];

extern const uint64_t matmul_id_mxfp4_f16_fp32_len;
extern const unsigned char matmul_id_mxfp4_f16_fp32_data[];

extern const uint64_t matmul_id_mxfp4_f32_len;
extern const unsigned char matmul_id_mxfp4_f32_data[];

extern const uint64_t matmul_id_mxfp4_f32_dot2_len;
extern const unsigned char matmul_id_mxfp4_f32_dot2_data[];

extern const uint64_t matmul_id_mxfp4_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_mxfp4_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_mxfp4_f32_f16acc_len;
extern const unsigned char matmul_id_mxfp4_f32_f16acc_data[];

extern const uint64_t matmul_id_mxfp4_f32_fp32_len;
extern const unsigned char matmul_id_mxfp4_f32_fp32_data[];

extern const uint64_t matmul_id_mxfp4_q8_1_len;
extern const unsigned char matmul_id_mxfp4_q8_1_data[];

extern const uint64_t matmul_id_mxfp4_q8_1_fp32_len;
extern const unsigned char matmul_id_mxfp4_q8_1_fp32_data[];

extern const uint64_t matmul_id_nvfp4_f16_len;
extern const unsigned char matmul_id_nvfp4_f16_data[];

extern const uint64_t matmul_id_nvfp4_f16_dot2_len;
extern const unsigned char matmul_id_nvfp4_f16_dot2_data[];

extern const uint64_t matmul_id_nvfp4_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_nvfp4_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_nvfp4_f16_f16acc_len;
extern const unsigned char matmul_id_nvfp4_f16_f16acc_data[];

extern const uint64_t matmul_id_nvfp4_f16_fp32_len;
extern const unsigned char matmul_id_nvfp4_f16_fp32_data[];

extern const uint64_t matmul_id_nvfp4_f32_len;
extern const unsigned char matmul_id_nvfp4_f32_data[];

extern const uint64_t matmul_id_nvfp4_f32_dot2_len;
extern const unsigned char matmul_id_nvfp4_f32_dot2_data[];

extern const uint64_t matmul_id_nvfp4_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_nvfp4_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_nvfp4_f32_f16acc_len;
extern const unsigned char matmul_id_nvfp4_f32_f16acc_data[];

extern const uint64_t matmul_id_nvfp4_f32_fp32_len;
extern const unsigned char matmul_id_nvfp4_f32_fp32_data[];

extern const uint64_t matmul_id_q1_0_f16_len;
extern const unsigned char matmul_id_q1_0_f16_data[];

extern const uint64_t matmul_id_q1_0_f16_dot2_len;
extern const unsigned char matmul_id_q1_0_f16_dot2_data[];

extern const uint64_t matmul_id_q1_0_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_q1_0_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_q1_0_f16_f16acc_len;
extern const unsigned char matmul_id_q1_0_f16_f16acc_data[];

extern const uint64_t matmul_id_q1_0_f16_fp32_len;
extern const unsigned char matmul_id_q1_0_f16_fp32_data[];

extern const uint64_t matmul_id_q1_0_f32_len;
extern const unsigned char matmul_id_q1_0_f32_data[];

extern const uint64_t matmul_id_q1_0_f32_dot2_len;
extern const unsigned char matmul_id_q1_0_f32_dot2_data[];

extern const uint64_t matmul_id_q1_0_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_q1_0_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_q1_0_f32_f16acc_len;
extern const unsigned char matmul_id_q1_0_f32_f16acc_data[];

extern const uint64_t matmul_id_q1_0_f32_fp32_len;
extern const unsigned char matmul_id_q1_0_f32_fp32_data[];

extern const uint64_t matmul_id_q2_k_f16_len;
extern const unsigned char matmul_id_q2_k_f16_data[];

extern const uint64_t matmul_id_q2_k_f16_dot2_len;
extern const unsigned char matmul_id_q2_k_f16_dot2_data[];

extern const uint64_t matmul_id_q2_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_q2_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_q2_k_f16_f16acc_len;
extern const unsigned char matmul_id_q2_k_f16_f16acc_data[];

extern const uint64_t matmul_id_q2_k_f16_fp32_len;
extern const unsigned char matmul_id_q2_k_f16_fp32_data[];

extern const uint64_t matmul_id_q2_k_f32_len;
extern const unsigned char matmul_id_q2_k_f32_data[];

extern const uint64_t matmul_id_q2_k_f32_dot2_len;
extern const unsigned char matmul_id_q2_k_f32_dot2_data[];

extern const uint64_t matmul_id_q2_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_q2_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_q2_k_f32_f16acc_len;
extern const unsigned char matmul_id_q2_k_f32_f16acc_data[];

extern const uint64_t matmul_id_q2_k_f32_fp32_len;
extern const unsigned char matmul_id_q2_k_f32_fp32_data[];

extern const uint64_t matmul_id_q2_k_q8_1_len;
extern const unsigned char matmul_id_q2_k_q8_1_data[];

extern const uint64_t matmul_id_q2_k_q8_1_fp32_len;
extern const unsigned char matmul_id_q2_k_q8_1_fp32_data[];

extern const uint64_t matmul_id_q3_k_f16_len;
extern const unsigned char matmul_id_q3_k_f16_data[];

extern const uint64_t matmul_id_q3_k_f16_dot2_len;
extern const unsigned char matmul_id_q3_k_f16_dot2_data[];

extern const uint64_t matmul_id_q3_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_q3_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_q3_k_f16_f16acc_len;
extern const unsigned char matmul_id_q3_k_f16_f16acc_data[];

extern const uint64_t matmul_id_q3_k_f16_fp32_len;
extern const unsigned char matmul_id_q3_k_f16_fp32_data[];

extern const uint64_t matmul_id_q3_k_f32_len;
extern const unsigned char matmul_id_q3_k_f32_data[];

extern const uint64_t matmul_id_q3_k_f32_dot2_len;
extern const unsigned char matmul_id_q3_k_f32_dot2_data[];

extern const uint64_t matmul_id_q3_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_q3_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_q3_k_f32_f16acc_len;
extern const unsigned char matmul_id_q3_k_f32_f16acc_data[];

extern const uint64_t matmul_id_q3_k_f32_fp32_len;
extern const unsigned char matmul_id_q3_k_f32_fp32_data[];

extern const uint64_t matmul_id_q3_k_q8_1_len;
extern const unsigned char matmul_id_q3_k_q8_1_data[];

extern const uint64_t matmul_id_q3_k_q8_1_fp32_len;
extern const unsigned char matmul_id_q3_k_q8_1_fp32_data[];

extern const uint64_t matmul_id_q4_0_f16_len;
extern const unsigned char matmul_id_q4_0_f16_data[];

extern const uint64_t matmul_id_q4_0_f16_dot2_len;
extern const unsigned char matmul_id_q4_0_f16_dot2_data[];

extern const uint64_t matmul_id_q4_0_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_q4_0_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_q4_0_f16_f16acc_len;
extern const unsigned char matmul_id_q4_0_f16_f16acc_data[];

extern const uint64_t matmul_id_q4_0_f16_fp32_len;
extern const unsigned char matmul_id_q4_0_f16_fp32_data[];

extern const uint64_t matmul_id_q4_0_f32_len;
extern const unsigned char matmul_id_q4_0_f32_data[];

extern const uint64_t matmul_id_q4_0_f32_dot2_len;
extern const unsigned char matmul_id_q4_0_f32_dot2_data[];

extern const uint64_t matmul_id_q4_0_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_q4_0_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_q4_0_f32_f16acc_len;
extern const unsigned char matmul_id_q4_0_f32_f16acc_data[];

extern const uint64_t matmul_id_q4_0_f32_fp32_len;
extern const unsigned char matmul_id_q4_0_f32_fp32_data[];

extern const uint64_t matmul_id_q4_0_q8_1_len;
extern const unsigned char matmul_id_q4_0_q8_1_data[];

extern const uint64_t matmul_id_q4_0_q8_1_fp32_len;
extern const unsigned char matmul_id_q4_0_q8_1_fp32_data[];

extern const uint64_t matmul_id_q4_1_f16_len;
extern const unsigned char matmul_id_q4_1_f16_data[];

extern const uint64_t matmul_id_q4_1_f16_dot2_len;
extern const unsigned char matmul_id_q4_1_f16_dot2_data[];

extern const uint64_t matmul_id_q4_1_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_q4_1_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_q4_1_f16_f16acc_len;
extern const unsigned char matmul_id_q4_1_f16_f16acc_data[];

extern const uint64_t matmul_id_q4_1_f16_fp32_len;
extern const unsigned char matmul_id_q4_1_f16_fp32_data[];

extern const uint64_t matmul_id_q4_1_f32_len;
extern const unsigned char matmul_id_q4_1_f32_data[];

extern const uint64_t matmul_id_q4_1_f32_dot2_len;
extern const unsigned char matmul_id_q4_1_f32_dot2_data[];

extern const uint64_t matmul_id_q4_1_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_q4_1_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_q4_1_f32_f16acc_len;
extern const unsigned char matmul_id_q4_1_f32_f16acc_data[];

extern const uint64_t matmul_id_q4_1_f32_fp32_len;
extern const unsigned char matmul_id_q4_1_f32_fp32_data[];

extern const uint64_t matmul_id_q4_1_q8_1_len;
extern const unsigned char matmul_id_q4_1_q8_1_data[];

extern const uint64_t matmul_id_q4_1_q8_1_fp32_len;
extern const unsigned char matmul_id_q4_1_q8_1_fp32_data[];

extern const uint64_t matmul_id_q4_k_f16_len;
extern const unsigned char matmul_id_q4_k_f16_data[];

extern const uint64_t matmul_id_q4_k_f16_dot2_len;
extern const unsigned char matmul_id_q4_k_f16_dot2_data[];

extern const uint64_t matmul_id_q4_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_q4_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_q4_k_f16_f16acc_len;
extern const unsigned char matmul_id_q4_k_f16_f16acc_data[];

extern const uint64_t matmul_id_q4_k_f16_fp32_len;
extern const unsigned char matmul_id_q4_k_f16_fp32_data[];

extern const uint64_t matmul_id_q4_k_f32_len;
extern const unsigned char matmul_id_q4_k_f32_data[];

extern const uint64_t matmul_id_q4_k_f32_dot2_len;
extern const unsigned char matmul_id_q4_k_f32_dot2_data[];

extern const uint64_t matmul_id_q4_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_q4_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_q4_k_f32_f16acc_len;
extern const unsigned char matmul_id_q4_k_f32_f16acc_data[];

extern const uint64_t matmul_id_q4_k_f32_fp32_len;
extern const unsigned char matmul_id_q4_k_f32_fp32_data[];

extern const uint64_t matmul_id_q4_k_q8_1_len;
extern const unsigned char matmul_id_q4_k_q8_1_data[];

extern const uint64_t matmul_id_q4_k_q8_1_fp32_len;
extern const unsigned char matmul_id_q4_k_q8_1_fp32_data[];

extern const uint64_t matmul_id_q5_0_f16_len;
extern const unsigned char matmul_id_q5_0_f16_data[];

extern const uint64_t matmul_id_q5_0_f16_dot2_len;
extern const unsigned char matmul_id_q5_0_f16_dot2_data[];

extern const uint64_t matmul_id_q5_0_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_q5_0_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_q5_0_f16_f16acc_len;
extern const unsigned char matmul_id_q5_0_f16_f16acc_data[];

extern const uint64_t matmul_id_q5_0_f16_fp32_len;
extern const unsigned char matmul_id_q5_0_f16_fp32_data[];

extern const uint64_t matmul_id_q5_0_f32_len;
extern const unsigned char matmul_id_q5_0_f32_data[];

extern const uint64_t matmul_id_q5_0_f32_dot2_len;
extern const unsigned char matmul_id_q5_0_f32_dot2_data[];

extern const uint64_t matmul_id_q5_0_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_q5_0_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_q5_0_f32_f16acc_len;
extern const unsigned char matmul_id_q5_0_f32_f16acc_data[];

extern const uint64_t matmul_id_q5_0_f32_fp32_len;
extern const unsigned char matmul_id_q5_0_f32_fp32_data[];

extern const uint64_t matmul_id_q5_0_q8_1_len;
extern const unsigned char matmul_id_q5_0_q8_1_data[];

extern const uint64_t matmul_id_q5_0_q8_1_fp32_len;
extern const unsigned char matmul_id_q5_0_q8_1_fp32_data[];

extern const uint64_t matmul_id_q5_1_f16_len;
extern const unsigned char matmul_id_q5_1_f16_data[];

extern const uint64_t matmul_id_q5_1_f16_dot2_len;
extern const unsigned char matmul_id_q5_1_f16_dot2_data[];

extern const uint64_t matmul_id_q5_1_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_q5_1_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_q5_1_f16_f16acc_len;
extern const unsigned char matmul_id_q5_1_f16_f16acc_data[];

extern const uint64_t matmul_id_q5_1_f16_fp32_len;
extern const unsigned char matmul_id_q5_1_f16_fp32_data[];

extern const uint64_t matmul_id_q5_1_f32_len;
extern const unsigned char matmul_id_q5_1_f32_data[];

extern const uint64_t matmul_id_q5_1_f32_dot2_len;
extern const unsigned char matmul_id_q5_1_f32_dot2_data[];

extern const uint64_t matmul_id_q5_1_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_q5_1_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_q5_1_f32_f16acc_len;
extern const unsigned char matmul_id_q5_1_f32_f16acc_data[];

extern const uint64_t matmul_id_q5_1_f32_fp32_len;
extern const unsigned char matmul_id_q5_1_f32_fp32_data[];

extern const uint64_t matmul_id_q5_1_q8_1_len;
extern const unsigned char matmul_id_q5_1_q8_1_data[];

extern const uint64_t matmul_id_q5_1_q8_1_fp32_len;
extern const unsigned char matmul_id_q5_1_q8_1_fp32_data[];

extern const uint64_t matmul_id_q5_k_f16_len;
extern const unsigned char matmul_id_q5_k_f16_data[];

extern const uint64_t matmul_id_q5_k_f16_dot2_len;
extern const unsigned char matmul_id_q5_k_f16_dot2_data[];

extern const uint64_t matmul_id_q5_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_q5_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_q5_k_f16_f16acc_len;
extern const unsigned char matmul_id_q5_k_f16_f16acc_data[];

extern const uint64_t matmul_id_q5_k_f16_fp32_len;
extern const unsigned char matmul_id_q5_k_f16_fp32_data[];

extern const uint64_t matmul_id_q5_k_f32_len;
extern const unsigned char matmul_id_q5_k_f32_data[];

extern const uint64_t matmul_id_q5_k_f32_dot2_len;
extern const unsigned char matmul_id_q5_k_f32_dot2_data[];

extern const uint64_t matmul_id_q5_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_q5_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_q5_k_f32_f16acc_len;
extern const unsigned char matmul_id_q5_k_f32_f16acc_data[];

extern const uint64_t matmul_id_q5_k_f32_fp32_len;
extern const unsigned char matmul_id_q5_k_f32_fp32_data[];

extern const uint64_t matmul_id_q5_k_q8_1_len;
extern const unsigned char matmul_id_q5_k_q8_1_data[];

extern const uint64_t matmul_id_q5_k_q8_1_fp32_len;
extern const unsigned char matmul_id_q5_k_q8_1_fp32_data[];

extern const uint64_t matmul_id_q6_k_f16_len;
extern const unsigned char matmul_id_q6_k_f16_data[];

extern const uint64_t matmul_id_q6_k_f16_dot2_len;
extern const unsigned char matmul_id_q6_k_f16_dot2_data[];

extern const uint64_t matmul_id_q6_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_q6_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_q6_k_f16_f16acc_len;
extern const unsigned char matmul_id_q6_k_f16_f16acc_data[];

extern const uint64_t matmul_id_q6_k_f16_fp32_len;
extern const unsigned char matmul_id_q6_k_f16_fp32_data[];

extern const uint64_t matmul_id_q6_k_f32_len;
extern const unsigned char matmul_id_q6_k_f32_data[];

extern const uint64_t matmul_id_q6_k_f32_dot2_len;
extern const unsigned char matmul_id_q6_k_f32_dot2_data[];

extern const uint64_t matmul_id_q6_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_q6_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_q6_k_f32_f16acc_len;
extern const unsigned char matmul_id_q6_k_f32_f16acc_data[];

extern const uint64_t matmul_id_q6_k_f32_fp32_len;
extern const unsigned char matmul_id_q6_k_f32_fp32_data[];

extern const uint64_t matmul_id_q6_k_q8_1_len;
extern const unsigned char matmul_id_q6_k_q8_1_data[];

extern const uint64_t matmul_id_q6_k_q8_1_fp32_len;
extern const unsigned char matmul_id_q6_k_q8_1_fp32_data[];

extern const uint64_t matmul_id_q8_0_f16_len;
extern const unsigned char matmul_id_q8_0_f16_data[];

extern const uint64_t matmul_id_q8_0_f16_dot2_len;
extern const unsigned char matmul_id_q8_0_f16_dot2_data[];

extern const uint64_t matmul_id_q8_0_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_q8_0_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_q8_0_f16_f16acc_len;
extern const unsigned char matmul_id_q8_0_f16_f16acc_data[];

extern const uint64_t matmul_id_q8_0_f16_fp32_len;
extern const unsigned char matmul_id_q8_0_f16_fp32_data[];

extern const uint64_t matmul_id_q8_0_f32_len;
extern const unsigned char matmul_id_q8_0_f32_data[];

extern const uint64_t matmul_id_q8_0_f32_dot2_len;
extern const unsigned char matmul_id_q8_0_f32_dot2_data[];

extern const uint64_t matmul_id_q8_0_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_q8_0_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_q8_0_f32_f16acc_len;
extern const unsigned char matmul_id_q8_0_f32_f16acc_data[];

extern const uint64_t matmul_id_q8_0_f32_fp32_len;
extern const unsigned char matmul_id_q8_0_f32_fp32_data[];

extern const uint64_t matmul_id_q8_0_q8_1_len;
extern const unsigned char matmul_id_q8_0_q8_1_data[];

extern const uint64_t matmul_id_q8_0_q8_1_fp32_len;
extern const unsigned char matmul_id_q8_0_q8_1_fp32_data[];

extern const uint64_t matmul_id_subgroup_bf16_len;
extern const unsigned char matmul_id_subgroup_bf16_data[];

extern const uint64_t matmul_id_subgroup_bf16_cm1_len;
extern const unsigned char matmul_id_subgroup_bf16_cm1_data[];

extern const uint64_t matmul_id_subgroup_bf16_cm2_len;
extern const unsigned char matmul_id_subgroup_bf16_cm2_data[];

extern const uint64_t matmul_id_subgroup_bf16_f16acc_len;
extern const unsigned char matmul_id_subgroup_bf16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_bf16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_bf16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_bf16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_bf16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_bf16_fp32_len;
extern const unsigned char matmul_id_subgroup_bf16_fp32_data[];

extern const uint64_t matmul_id_subgroup_f16_len;
extern const unsigned char matmul_id_subgroup_f16_data[];

extern const uint64_t matmul_id_subgroup_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_f16_f32_len;
extern const unsigned char matmul_id_subgroup_f16_f32_data[];

extern const uint64_t matmul_id_subgroup_f16_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_f16_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_f16_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_f16_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_f16_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_f16_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_f16_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_f16_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_f16_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_f16_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_f16_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_f16_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_f32_f16_len;
extern const unsigned char matmul_id_subgroup_f32_f16_data[];

extern const uint64_t matmul_id_subgroup_f32_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_f32_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_f32_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_f32_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_f32_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_f32_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_f32_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_f32_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_f32_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_f32_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_f32_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_f32_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_f32_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_f32_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_f32_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_f32_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_f32_f32_len;
extern const unsigned char matmul_id_subgroup_f32_f32_data[];

extern const uint64_t matmul_id_subgroup_f32_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_f32_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_f32_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_f32_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_f32_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_f32_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_f32_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_f32_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_f32_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_f32_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_f32_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_f32_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f16_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f16_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f32_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f32_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq1_m_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_iq1_m_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f16_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f16_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f32_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f32_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq1_s_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_iq1_s_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f16_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f16_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f32_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f32_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq2_s_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_iq2_s_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f16_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f16_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f32_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f32_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq2_xs_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_iq2_xs_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f16_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f16_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f32_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f32_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq2_xxs_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_iq2_xxs_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f16_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f16_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f32_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f32_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq3_s_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_iq3_s_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f16_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f16_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f32_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f32_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq3_xxs_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_iq3_xxs_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f16_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f16_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f32_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f32_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq4_nl_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_iq4_nl_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f16_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f16_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f32_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f32_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_iq4_xs_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_iq4_xs_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f16_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f16_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f32_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f32_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_mxfp4_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_q8_1_len;
extern const unsigned char matmul_id_subgroup_mxfp4_q8_1_data[];

extern const uint64_t matmul_id_subgroup_mxfp4_q8_1_fp32_len;
extern const unsigned char matmul_id_subgroup_mxfp4_q8_1_fp32_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f16_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f16_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f32_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f32_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_nvfp4_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_nvfp4_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f16_len;
extern const unsigned char matmul_id_subgroup_q1_0_f16_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_q1_0_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_q1_0_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_q1_0_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q1_0_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_q1_0_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q1_0_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_q1_0_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_q1_0_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f32_len;
extern const unsigned char matmul_id_subgroup_q1_0_f32_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_q1_0_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_q1_0_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q1_0_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_q1_0_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q1_0_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q1_0_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_q1_0_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f16_len;
extern const unsigned char matmul_id_subgroup_q2_k_f16_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_q2_k_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_q2_k_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_q2_k_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q2_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_q2_k_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q2_k_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_q2_k_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_q2_k_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f32_len;
extern const unsigned char matmul_id_subgroup_q2_k_f32_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_q2_k_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_q2_k_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q2_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_q2_k_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q2_k_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q2_k_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_q2_k_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_q2_k_q8_1_len;
extern const unsigned char matmul_id_subgroup_q2_k_q8_1_data[];

extern const uint64_t matmul_id_subgroup_q2_k_q8_1_fp32_len;
extern const unsigned char matmul_id_subgroup_q2_k_q8_1_fp32_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f16_len;
extern const unsigned char matmul_id_subgroup_q3_k_f16_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_q3_k_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_q3_k_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_q3_k_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q3_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_q3_k_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q3_k_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_q3_k_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_q3_k_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f32_len;
extern const unsigned char matmul_id_subgroup_q3_k_f32_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_q3_k_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_q3_k_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q3_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_q3_k_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q3_k_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q3_k_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_q3_k_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_q3_k_q8_1_len;
extern const unsigned char matmul_id_subgroup_q3_k_q8_1_data[];

extern const uint64_t matmul_id_subgroup_q3_k_q8_1_fp32_len;
extern const unsigned char matmul_id_subgroup_q3_k_q8_1_fp32_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f16_len;
extern const unsigned char matmul_id_subgroup_q4_0_f16_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_q4_0_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_q4_0_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_q4_0_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q4_0_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_q4_0_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q4_0_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_q4_0_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_q4_0_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f32_len;
extern const unsigned char matmul_id_subgroup_q4_0_f32_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_q4_0_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_q4_0_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q4_0_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_q4_0_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q4_0_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q4_0_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_q4_0_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_q4_0_q8_1_len;
extern const unsigned char matmul_id_subgroup_q4_0_q8_1_data[];

extern const uint64_t matmul_id_subgroup_q4_0_q8_1_fp32_len;
extern const unsigned char matmul_id_subgroup_q4_0_q8_1_fp32_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f16_len;
extern const unsigned char matmul_id_subgroup_q4_1_f16_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_q4_1_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_q4_1_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_q4_1_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q4_1_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_q4_1_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q4_1_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_q4_1_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_q4_1_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f32_len;
extern const unsigned char matmul_id_subgroup_q4_1_f32_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_q4_1_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_q4_1_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q4_1_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_q4_1_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q4_1_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q4_1_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_q4_1_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_q4_1_q8_1_len;
extern const unsigned char matmul_id_subgroup_q4_1_q8_1_data[];

extern const uint64_t matmul_id_subgroup_q4_1_q8_1_fp32_len;
extern const unsigned char matmul_id_subgroup_q4_1_q8_1_fp32_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f16_len;
extern const unsigned char matmul_id_subgroup_q4_k_f16_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_q4_k_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_q4_k_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_q4_k_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q4_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_q4_k_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q4_k_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_q4_k_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_q4_k_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f32_len;
extern const unsigned char matmul_id_subgroup_q4_k_f32_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_q4_k_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_q4_k_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q4_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_q4_k_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q4_k_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q4_k_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_q4_k_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_q4_k_q8_1_len;
extern const unsigned char matmul_id_subgroup_q4_k_q8_1_data[];

extern const uint64_t matmul_id_subgroup_q4_k_q8_1_fp32_len;
extern const unsigned char matmul_id_subgroup_q4_k_q8_1_fp32_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f16_len;
extern const unsigned char matmul_id_subgroup_q5_0_f16_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_q5_0_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_q5_0_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_q5_0_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q5_0_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_q5_0_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q5_0_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_q5_0_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_q5_0_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f32_len;
extern const unsigned char matmul_id_subgroup_q5_0_f32_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_q5_0_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_q5_0_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q5_0_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_q5_0_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q5_0_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q5_0_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_q5_0_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_q5_0_q8_1_len;
extern const unsigned char matmul_id_subgroup_q5_0_q8_1_data[];

extern const uint64_t matmul_id_subgroup_q5_0_q8_1_fp32_len;
extern const unsigned char matmul_id_subgroup_q5_0_q8_1_fp32_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f16_len;
extern const unsigned char matmul_id_subgroup_q5_1_f16_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_q5_1_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_q5_1_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_q5_1_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q5_1_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_q5_1_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q5_1_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_q5_1_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_q5_1_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f32_len;
extern const unsigned char matmul_id_subgroup_q5_1_f32_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_q5_1_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_q5_1_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q5_1_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_q5_1_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q5_1_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q5_1_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_q5_1_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_q5_1_q8_1_len;
extern const unsigned char matmul_id_subgroup_q5_1_q8_1_data[];

extern const uint64_t matmul_id_subgroup_q5_1_q8_1_fp32_len;
extern const unsigned char matmul_id_subgroup_q5_1_q8_1_fp32_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f16_len;
extern const unsigned char matmul_id_subgroup_q5_k_f16_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_q5_k_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_q5_k_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_q5_k_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q5_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_q5_k_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q5_k_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_q5_k_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_q5_k_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f32_len;
extern const unsigned char matmul_id_subgroup_q5_k_f32_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_q5_k_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_q5_k_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q5_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_q5_k_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q5_k_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q5_k_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_q5_k_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_q5_k_q8_1_len;
extern const unsigned char matmul_id_subgroup_q5_k_q8_1_data[];

extern const uint64_t matmul_id_subgroup_q5_k_q8_1_fp32_len;
extern const unsigned char matmul_id_subgroup_q5_k_q8_1_fp32_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f16_len;
extern const unsigned char matmul_id_subgroup_q6_k_f16_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_q6_k_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_q6_k_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_q6_k_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q6_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_q6_k_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q6_k_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_q6_k_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_q6_k_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f32_len;
extern const unsigned char matmul_id_subgroup_q6_k_f32_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_q6_k_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_q6_k_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q6_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_q6_k_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q6_k_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q6_k_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_q6_k_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_q6_k_q8_1_len;
extern const unsigned char matmul_id_subgroup_q6_k_q8_1_data[];

extern const uint64_t matmul_id_subgroup_q6_k_q8_1_fp32_len;
extern const unsigned char matmul_id_subgroup_q6_k_q8_1_fp32_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f16_len;
extern const unsigned char matmul_id_subgroup_q8_0_f16_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f16_cm1_len;
extern const unsigned char matmul_id_subgroup_q8_0_f16_cm1_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f16_cm2_len;
extern const unsigned char matmul_id_subgroup_q8_0_f16_cm2_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f16_dot2_len;
extern const unsigned char matmul_id_subgroup_q8_0_f16_dot2_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f16_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q8_0_f16_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f16_f16acc_len;
extern const unsigned char matmul_id_subgroup_q8_0_f16_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f16_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q8_0_f16_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f16_f16acc_cm2_len;
extern const unsigned char matmul_id_subgroup_q8_0_f16_f16acc_cm2_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f16_fp32_len;
extern const unsigned char matmul_id_subgroup_q8_0_f16_fp32_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f32_len;
extern const unsigned char matmul_id_subgroup_q8_0_f32_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f32_cm1_len;
extern const unsigned char matmul_id_subgroup_q8_0_f32_cm1_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f32_dot2_len;
extern const unsigned char matmul_id_subgroup_q8_0_f32_dot2_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f32_dot2_f16acc_len;
extern const unsigned char matmul_id_subgroup_q8_0_f32_dot2_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f32_f16acc_len;
extern const unsigned char matmul_id_subgroup_q8_0_f32_f16acc_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f32_f16acc_cm1_len;
extern const unsigned char matmul_id_subgroup_q8_0_f32_f16acc_cm1_data[];

extern const uint64_t matmul_id_subgroup_q8_0_f32_fp32_len;
extern const unsigned char matmul_id_subgroup_q8_0_f32_fp32_data[];

extern const uint64_t matmul_id_subgroup_q8_0_q8_1_len;
extern const unsigned char matmul_id_subgroup_q8_0_q8_1_data[];

extern const uint64_t matmul_id_subgroup_q8_0_q8_1_fp32_len;
extern const unsigned char matmul_id_subgroup_q8_0_q8_1_fp32_data[];

extern const uint64_t matmul_iq1_m_f16_len;
extern const unsigned char matmul_iq1_m_f16_data[];

extern const uint64_t matmul_iq1_m_f16_cm1_len;
extern const unsigned char matmul_iq1_m_f16_cm1_data[];

extern const uint64_t matmul_iq1_m_f16_cm2_len;
extern const unsigned char matmul_iq1_m_f16_cm2_data[];

extern const uint64_t matmul_iq1_m_f16_dot2_len;
extern const unsigned char matmul_iq1_m_f16_dot2_data[];

extern const uint64_t matmul_iq1_m_f16_dot2_f16acc_len;
extern const unsigned char matmul_iq1_m_f16_dot2_f16acc_data[];

extern const uint64_t matmul_iq1_m_f16_f16acc_len;
extern const unsigned char matmul_iq1_m_f16_f16acc_data[];

extern const uint64_t matmul_iq1_m_f16_f16acc_cm1_len;
extern const unsigned char matmul_iq1_m_f16_f16acc_cm1_data[];

extern const uint64_t matmul_iq1_m_f16_f16acc_cm2_len;
extern const unsigned char matmul_iq1_m_f16_f16acc_cm2_data[];

extern const uint64_t matmul_iq1_m_f16_fp32_len;
extern const unsigned char matmul_iq1_m_f16_fp32_data[];

extern const uint64_t matmul_iq1_m_f32_len;
extern const unsigned char matmul_iq1_m_f32_data[];

extern const uint64_t matmul_iq1_m_f32_cm1_len;
extern const unsigned char matmul_iq1_m_f32_cm1_data[];

extern const uint64_t matmul_iq1_m_f32_dot2_len;
extern const unsigned char matmul_iq1_m_f32_dot2_data[];

extern const uint64_t matmul_iq1_m_f32_dot2_f16acc_len;
extern const unsigned char matmul_iq1_m_f32_dot2_f16acc_data[];

extern const uint64_t matmul_iq1_m_f32_f16acc_len;
extern const unsigned char matmul_iq1_m_f32_f16acc_data[];

extern const uint64_t matmul_iq1_m_f32_f16acc_cm1_len;
extern const unsigned char matmul_iq1_m_f32_f16acc_cm1_data[];

extern const uint64_t matmul_iq1_m_f32_fp32_len;
extern const unsigned char matmul_iq1_m_f32_fp32_data[];

extern const uint64_t matmul_iq1_s_f16_len;
extern const unsigned char matmul_iq1_s_f16_data[];

extern const uint64_t matmul_iq1_s_f16_cm1_len;
extern const unsigned char matmul_iq1_s_f16_cm1_data[];

extern const uint64_t matmul_iq1_s_f16_cm2_len;
extern const unsigned char matmul_iq1_s_f16_cm2_data[];

extern const uint64_t matmul_iq1_s_f16_dot2_len;
extern const unsigned char matmul_iq1_s_f16_dot2_data[];

extern const uint64_t matmul_iq1_s_f16_dot2_f16acc_len;
extern const unsigned char matmul_iq1_s_f16_dot2_f16acc_data[];

extern const uint64_t matmul_iq1_s_f16_f16acc_len;
extern const unsigned char matmul_iq1_s_f16_f16acc_data[];

extern const uint64_t matmul_iq1_s_f16_f16acc_cm1_len;
extern const unsigned char matmul_iq1_s_f16_f16acc_cm1_data[];

extern const uint64_t matmul_iq1_s_f16_f16acc_cm2_len;
extern const unsigned char matmul_iq1_s_f16_f16acc_cm2_data[];

extern const uint64_t matmul_iq1_s_f16_fp32_len;
extern const unsigned char matmul_iq1_s_f16_fp32_data[];

extern const uint64_t matmul_iq1_s_f32_len;
extern const unsigned char matmul_iq1_s_f32_data[];

extern const uint64_t matmul_iq1_s_f32_cm1_len;
extern const unsigned char matmul_iq1_s_f32_cm1_data[];

extern const uint64_t matmul_iq1_s_f32_dot2_len;
extern const unsigned char matmul_iq1_s_f32_dot2_data[];

extern const uint64_t matmul_iq1_s_f32_dot2_f16acc_len;
extern const unsigned char matmul_iq1_s_f32_dot2_f16acc_data[];

extern const uint64_t matmul_iq1_s_f32_f16acc_len;
extern const unsigned char matmul_iq1_s_f32_f16acc_data[];

extern const uint64_t matmul_iq1_s_f32_f16acc_cm1_len;
extern const unsigned char matmul_iq1_s_f32_f16acc_cm1_data[];

extern const uint64_t matmul_iq1_s_f32_fp32_len;
extern const unsigned char matmul_iq1_s_f32_fp32_data[];

extern const uint64_t matmul_iq2_s_f16_len;
extern const unsigned char matmul_iq2_s_f16_data[];

extern const uint64_t matmul_iq2_s_f16_cm1_len;
extern const unsigned char matmul_iq2_s_f16_cm1_data[];

extern const uint64_t matmul_iq2_s_f16_cm2_len;
extern const unsigned char matmul_iq2_s_f16_cm2_data[];

extern const uint64_t matmul_iq2_s_f16_dot2_len;
extern const unsigned char matmul_iq2_s_f16_dot2_data[];

extern const uint64_t matmul_iq2_s_f16_dot2_f16acc_len;
extern const unsigned char matmul_iq2_s_f16_dot2_f16acc_data[];

extern const uint64_t matmul_iq2_s_f16_f16acc_len;
extern const unsigned char matmul_iq2_s_f16_f16acc_data[];

extern const uint64_t matmul_iq2_s_f16_f16acc_cm1_len;
extern const unsigned char matmul_iq2_s_f16_f16acc_cm1_data[];

extern const uint64_t matmul_iq2_s_f16_f16acc_cm2_len;
extern const unsigned char matmul_iq2_s_f16_f16acc_cm2_data[];

extern const uint64_t matmul_iq2_s_f16_fp32_len;
extern const unsigned char matmul_iq2_s_f16_fp32_data[];

extern const uint64_t matmul_iq2_s_f32_len;
extern const unsigned char matmul_iq2_s_f32_data[];

extern const uint64_t matmul_iq2_s_f32_cm1_len;
extern const unsigned char matmul_iq2_s_f32_cm1_data[];

extern const uint64_t matmul_iq2_s_f32_dot2_len;
extern const unsigned char matmul_iq2_s_f32_dot2_data[];

extern const uint64_t matmul_iq2_s_f32_dot2_f16acc_len;
extern const unsigned char matmul_iq2_s_f32_dot2_f16acc_data[];

extern const uint64_t matmul_iq2_s_f32_f16acc_len;
extern const unsigned char matmul_iq2_s_f32_f16acc_data[];

extern const uint64_t matmul_iq2_s_f32_f16acc_cm1_len;
extern const unsigned char matmul_iq2_s_f32_f16acc_cm1_data[];

extern const uint64_t matmul_iq2_s_f32_fp32_len;
extern const unsigned char matmul_iq2_s_f32_fp32_data[];

extern const uint64_t matmul_iq2_xs_f16_len;
extern const unsigned char matmul_iq2_xs_f16_data[];

extern const uint64_t matmul_iq2_xs_f16_cm1_len;
extern const unsigned char matmul_iq2_xs_f16_cm1_data[];

extern const uint64_t matmul_iq2_xs_f16_cm2_len;
extern const unsigned char matmul_iq2_xs_f16_cm2_data[];

extern const uint64_t matmul_iq2_xs_f16_dot2_len;
extern const unsigned char matmul_iq2_xs_f16_dot2_data[];

extern const uint64_t matmul_iq2_xs_f16_dot2_f16acc_len;
extern const unsigned char matmul_iq2_xs_f16_dot2_f16acc_data[];

extern const uint64_t matmul_iq2_xs_f16_f16acc_len;
extern const unsigned char matmul_iq2_xs_f16_f16acc_data[];

extern const uint64_t matmul_iq2_xs_f16_f16acc_cm1_len;
extern const unsigned char matmul_iq2_xs_f16_f16acc_cm1_data[];

extern const uint64_t matmul_iq2_xs_f16_f16acc_cm2_len;
extern const unsigned char matmul_iq2_xs_f16_f16acc_cm2_data[];

extern const uint64_t matmul_iq2_xs_f16_fp32_len;
extern const unsigned char matmul_iq2_xs_f16_fp32_data[];

extern const uint64_t matmul_iq2_xs_f32_len;
extern const unsigned char matmul_iq2_xs_f32_data[];

extern const uint64_t matmul_iq2_xs_f32_cm1_len;
extern const unsigned char matmul_iq2_xs_f32_cm1_data[];

extern const uint64_t matmul_iq2_xs_f32_dot2_len;
extern const unsigned char matmul_iq2_xs_f32_dot2_data[];

extern const uint64_t matmul_iq2_xs_f32_dot2_f16acc_len;
extern const unsigned char matmul_iq2_xs_f32_dot2_f16acc_data[];

extern const uint64_t matmul_iq2_xs_f32_f16acc_len;
extern const unsigned char matmul_iq2_xs_f32_f16acc_data[];

extern const uint64_t matmul_iq2_xs_f32_f16acc_cm1_len;
extern const unsigned char matmul_iq2_xs_f32_f16acc_cm1_data[];

extern const uint64_t matmul_iq2_xs_f32_fp32_len;
extern const unsigned char matmul_iq2_xs_f32_fp32_data[];

extern const uint64_t matmul_iq2_xxs_f16_len;
extern const unsigned char matmul_iq2_xxs_f16_data[];

extern const uint64_t matmul_iq2_xxs_f16_cm1_len;
extern const unsigned char matmul_iq2_xxs_f16_cm1_data[];

extern const uint64_t matmul_iq2_xxs_f16_cm2_len;
extern const unsigned char matmul_iq2_xxs_f16_cm2_data[];

extern const uint64_t matmul_iq2_xxs_f16_dot2_len;
extern const unsigned char matmul_iq2_xxs_f16_dot2_data[];

extern const uint64_t matmul_iq2_xxs_f16_dot2_f16acc_len;
extern const unsigned char matmul_iq2_xxs_f16_dot2_f16acc_data[];

extern const uint64_t matmul_iq2_xxs_f16_f16acc_len;
extern const unsigned char matmul_iq2_xxs_f16_f16acc_data[];

extern const uint64_t matmul_iq2_xxs_f16_f16acc_cm1_len;
extern const unsigned char matmul_iq2_xxs_f16_f16acc_cm1_data[];

extern const uint64_t matmul_iq2_xxs_f16_f16acc_cm2_len;
extern const unsigned char matmul_iq2_xxs_f16_f16acc_cm2_data[];

extern const uint64_t matmul_iq2_xxs_f16_fp32_len;
extern const unsigned char matmul_iq2_xxs_f16_fp32_data[];

extern const uint64_t matmul_iq2_xxs_f32_len;
extern const unsigned char matmul_iq2_xxs_f32_data[];

extern const uint64_t matmul_iq2_xxs_f32_cm1_len;
extern const unsigned char matmul_iq2_xxs_f32_cm1_data[];

extern const uint64_t matmul_iq2_xxs_f32_dot2_len;
extern const unsigned char matmul_iq2_xxs_f32_dot2_data[];

extern const uint64_t matmul_iq2_xxs_f32_dot2_f16acc_len;
extern const unsigned char matmul_iq2_xxs_f32_dot2_f16acc_data[];

extern const uint64_t matmul_iq2_xxs_f32_f16acc_len;
extern const unsigned char matmul_iq2_xxs_f32_f16acc_data[];

extern const uint64_t matmul_iq2_xxs_f32_f16acc_cm1_len;
extern const unsigned char matmul_iq2_xxs_f32_f16acc_cm1_data[];

extern const uint64_t matmul_iq2_xxs_f32_fp32_len;
extern const unsigned char matmul_iq2_xxs_f32_fp32_data[];

extern const uint64_t matmul_iq3_s_f16_len;
extern const unsigned char matmul_iq3_s_f16_data[];

extern const uint64_t matmul_iq3_s_f16_cm1_len;
extern const unsigned char matmul_iq3_s_f16_cm1_data[];

extern const uint64_t matmul_iq3_s_f16_cm2_len;
extern const unsigned char matmul_iq3_s_f16_cm2_data[];

extern const uint64_t matmul_iq3_s_f16_dot2_len;
extern const unsigned char matmul_iq3_s_f16_dot2_data[];

extern const uint64_t matmul_iq3_s_f16_dot2_f16acc_len;
extern const unsigned char matmul_iq3_s_f16_dot2_f16acc_data[];

extern const uint64_t matmul_iq3_s_f16_f16acc_len;
extern const unsigned char matmul_iq3_s_f16_f16acc_data[];

extern const uint64_t matmul_iq3_s_f16_f16acc_cm1_len;
extern const unsigned char matmul_iq3_s_f16_f16acc_cm1_data[];

extern const uint64_t matmul_iq3_s_f16_f16acc_cm2_len;
extern const unsigned char matmul_iq3_s_f16_f16acc_cm2_data[];

extern const uint64_t matmul_iq3_s_f16_fp32_len;
extern const unsigned char matmul_iq3_s_f16_fp32_data[];

extern const uint64_t matmul_iq3_s_f32_len;
extern const unsigned char matmul_iq3_s_f32_data[];

extern const uint64_t matmul_iq3_s_f32_cm1_len;
extern const unsigned char matmul_iq3_s_f32_cm1_data[];

extern const uint64_t matmul_iq3_s_f32_dot2_len;
extern const unsigned char matmul_iq3_s_f32_dot2_data[];

extern const uint64_t matmul_iq3_s_f32_dot2_f16acc_len;
extern const unsigned char matmul_iq3_s_f32_dot2_f16acc_data[];

extern const uint64_t matmul_iq3_s_f32_f16acc_len;
extern const unsigned char matmul_iq3_s_f32_f16acc_data[];

extern const uint64_t matmul_iq3_s_f32_f16acc_cm1_len;
extern const unsigned char matmul_iq3_s_f32_f16acc_cm1_data[];

extern const uint64_t matmul_iq3_s_f32_fp32_len;
extern const unsigned char matmul_iq3_s_f32_fp32_data[];

extern const uint64_t matmul_iq3_xxs_f16_len;
extern const unsigned char matmul_iq3_xxs_f16_data[];

extern const uint64_t matmul_iq3_xxs_f16_cm1_len;
extern const unsigned char matmul_iq3_xxs_f16_cm1_data[];

extern const uint64_t matmul_iq3_xxs_f16_cm2_len;
extern const unsigned char matmul_iq3_xxs_f16_cm2_data[];

extern const uint64_t matmul_iq3_xxs_f16_dot2_len;
extern const unsigned char matmul_iq3_xxs_f16_dot2_data[];

extern const uint64_t matmul_iq3_xxs_f16_dot2_f16acc_len;
extern const unsigned char matmul_iq3_xxs_f16_dot2_f16acc_data[];

extern const uint64_t matmul_iq3_xxs_f16_f16acc_len;
extern const unsigned char matmul_iq3_xxs_f16_f16acc_data[];

extern const uint64_t matmul_iq3_xxs_f16_f16acc_cm1_len;
extern const unsigned char matmul_iq3_xxs_f16_f16acc_cm1_data[];

extern const uint64_t matmul_iq3_xxs_f16_f16acc_cm2_len;
extern const unsigned char matmul_iq3_xxs_f16_f16acc_cm2_data[];

extern const uint64_t matmul_iq3_xxs_f16_fp32_len;
extern const unsigned char matmul_iq3_xxs_f16_fp32_data[];

extern const uint64_t matmul_iq3_xxs_f32_len;
extern const unsigned char matmul_iq3_xxs_f32_data[];

extern const uint64_t matmul_iq3_xxs_f32_cm1_len;
extern const unsigned char matmul_iq3_xxs_f32_cm1_data[];

extern const uint64_t matmul_iq3_xxs_f32_dot2_len;
extern const unsigned char matmul_iq3_xxs_f32_dot2_data[];

extern const uint64_t matmul_iq3_xxs_f32_dot2_f16acc_len;
extern const unsigned char matmul_iq3_xxs_f32_dot2_f16acc_data[];

extern const uint64_t matmul_iq3_xxs_f32_f16acc_len;
extern const unsigned char matmul_iq3_xxs_f32_f16acc_data[];

extern const uint64_t matmul_iq3_xxs_f32_f16acc_cm1_len;
extern const unsigned char matmul_iq3_xxs_f32_f16acc_cm1_data[];

extern const uint64_t matmul_iq3_xxs_f32_fp32_len;
extern const unsigned char matmul_iq3_xxs_f32_fp32_data[];

extern const uint64_t matmul_iq4_nl_f16_len;
extern const unsigned char matmul_iq4_nl_f16_data[];

extern const uint64_t matmul_iq4_nl_f16_cm1_len;
extern const unsigned char matmul_iq4_nl_f16_cm1_data[];

extern const uint64_t matmul_iq4_nl_f16_cm2_len;
extern const unsigned char matmul_iq4_nl_f16_cm2_data[];

extern const uint64_t matmul_iq4_nl_f16_dot2_len;
extern const unsigned char matmul_iq4_nl_f16_dot2_data[];

extern const uint64_t matmul_iq4_nl_f16_dot2_f16acc_len;
extern const unsigned char matmul_iq4_nl_f16_dot2_f16acc_data[];

extern const uint64_t matmul_iq4_nl_f16_f16acc_len;
extern const unsigned char matmul_iq4_nl_f16_f16acc_data[];

extern const uint64_t matmul_iq4_nl_f16_f16acc_cm1_len;
extern const unsigned char matmul_iq4_nl_f16_f16acc_cm1_data[];

extern const uint64_t matmul_iq4_nl_f16_f16acc_cm2_len;
extern const unsigned char matmul_iq4_nl_f16_f16acc_cm2_data[];

extern const uint64_t matmul_iq4_nl_f16_fp32_len;
extern const unsigned char matmul_iq4_nl_f16_fp32_data[];

extern const uint64_t matmul_iq4_nl_f32_len;
extern const unsigned char matmul_iq4_nl_f32_data[];

extern const uint64_t matmul_iq4_nl_f32_cm1_len;
extern const unsigned char matmul_iq4_nl_f32_cm1_data[];

extern const uint64_t matmul_iq4_nl_f32_dot2_len;
extern const unsigned char matmul_iq4_nl_f32_dot2_data[];

extern const uint64_t matmul_iq4_nl_f32_dot2_f16acc_len;
extern const unsigned char matmul_iq4_nl_f32_dot2_f16acc_data[];

extern const uint64_t matmul_iq4_nl_f32_f16acc_len;
extern const unsigned char matmul_iq4_nl_f32_f16acc_data[];

extern const uint64_t matmul_iq4_nl_f32_f16acc_cm1_len;
extern const unsigned char matmul_iq4_nl_f32_f16acc_cm1_data[];

extern const uint64_t matmul_iq4_nl_f32_fp32_len;
extern const unsigned char matmul_iq4_nl_f32_fp32_data[];

extern const uint64_t matmul_iq4_xs_f16_len;
extern const unsigned char matmul_iq4_xs_f16_data[];

extern const uint64_t matmul_iq4_xs_f16_cm1_len;
extern const unsigned char matmul_iq4_xs_f16_cm1_data[];

extern const uint64_t matmul_iq4_xs_f16_cm2_len;
extern const unsigned char matmul_iq4_xs_f16_cm2_data[];

extern const uint64_t matmul_iq4_xs_f16_dot2_len;
extern const unsigned char matmul_iq4_xs_f16_dot2_data[];

extern const uint64_t matmul_iq4_xs_f16_dot2_f16acc_len;
extern const unsigned char matmul_iq4_xs_f16_dot2_f16acc_data[];

extern const uint64_t matmul_iq4_xs_f16_f16acc_len;
extern const unsigned char matmul_iq4_xs_f16_f16acc_data[];

extern const uint64_t matmul_iq4_xs_f16_f16acc_cm1_len;
extern const unsigned char matmul_iq4_xs_f16_f16acc_cm1_data[];

extern const uint64_t matmul_iq4_xs_f16_f16acc_cm2_len;
extern const unsigned char matmul_iq4_xs_f16_f16acc_cm2_data[];

extern const uint64_t matmul_iq4_xs_f16_fp32_len;
extern const unsigned char matmul_iq4_xs_f16_fp32_data[];

extern const uint64_t matmul_iq4_xs_f32_len;
extern const unsigned char matmul_iq4_xs_f32_data[];

extern const uint64_t matmul_iq4_xs_f32_cm1_len;
extern const unsigned char matmul_iq4_xs_f32_cm1_data[];

extern const uint64_t matmul_iq4_xs_f32_dot2_len;
extern const unsigned char matmul_iq4_xs_f32_dot2_data[];

extern const uint64_t matmul_iq4_xs_f32_dot2_f16acc_len;
extern const unsigned char matmul_iq4_xs_f32_dot2_f16acc_data[];

extern const uint64_t matmul_iq4_xs_f32_f16acc_len;
extern const unsigned char matmul_iq4_xs_f32_f16acc_data[];

extern const uint64_t matmul_iq4_xs_f32_f16acc_cm1_len;
extern const unsigned char matmul_iq4_xs_f32_f16acc_cm1_data[];

extern const uint64_t matmul_iq4_xs_f32_fp32_len;
extern const unsigned char matmul_iq4_xs_f32_fp32_data[];

extern const uint64_t matmul_mxfp4_f16_len;
extern const unsigned char matmul_mxfp4_f16_data[];

extern const uint64_t matmul_mxfp4_f16_cm1_len;
extern const unsigned char matmul_mxfp4_f16_cm1_data[];

extern const uint64_t matmul_mxfp4_f16_cm2_len;
extern const unsigned char matmul_mxfp4_f16_cm2_data[];

extern const uint64_t matmul_mxfp4_f16_dot2_len;
extern const unsigned char matmul_mxfp4_f16_dot2_data[];

extern const uint64_t matmul_mxfp4_f16_dot2_f16acc_len;
extern const unsigned char matmul_mxfp4_f16_dot2_f16acc_data[];

extern const uint64_t matmul_mxfp4_f16_f16acc_len;
extern const unsigned char matmul_mxfp4_f16_f16acc_data[];

extern const uint64_t matmul_mxfp4_f16_f16acc_cm1_len;
extern const unsigned char matmul_mxfp4_f16_f16acc_cm1_data[];

extern const uint64_t matmul_mxfp4_f16_f16acc_cm2_len;
extern const unsigned char matmul_mxfp4_f16_f16acc_cm2_data[];

extern const uint64_t matmul_mxfp4_f16_fp32_len;
extern const unsigned char matmul_mxfp4_f16_fp32_data[];

extern const uint64_t matmul_mxfp4_f32_len;
extern const unsigned char matmul_mxfp4_f32_data[];

extern const uint64_t matmul_mxfp4_f32_cm1_len;
extern const unsigned char matmul_mxfp4_f32_cm1_data[];

extern const uint64_t matmul_mxfp4_f32_dot2_len;
extern const unsigned char matmul_mxfp4_f32_dot2_data[];

extern const uint64_t matmul_mxfp4_f32_dot2_f16acc_len;
extern const unsigned char matmul_mxfp4_f32_dot2_f16acc_data[];

extern const uint64_t matmul_mxfp4_f32_f16acc_len;
extern const unsigned char matmul_mxfp4_f32_f16acc_data[];

extern const uint64_t matmul_mxfp4_f32_f16acc_cm1_len;
extern const unsigned char matmul_mxfp4_f32_f16acc_cm1_data[];

extern const uint64_t matmul_mxfp4_f32_fp32_len;
extern const unsigned char matmul_mxfp4_f32_fp32_data[];

extern const uint64_t matmul_mxfp4_q8_1_len;
extern const unsigned char matmul_mxfp4_q8_1_data[];

extern const uint64_t matmul_mxfp4_q8_1_fp32_len;
extern const unsigned char matmul_mxfp4_q8_1_fp32_data[];

extern const uint64_t matmul_nvfp4_f16_len;
extern const unsigned char matmul_nvfp4_f16_data[];

extern const uint64_t matmul_nvfp4_f16_cm1_len;
extern const unsigned char matmul_nvfp4_f16_cm1_data[];

extern const uint64_t matmul_nvfp4_f16_cm2_len;
extern const unsigned char matmul_nvfp4_f16_cm2_data[];

extern const uint64_t matmul_nvfp4_f16_dot2_len;
extern const unsigned char matmul_nvfp4_f16_dot2_data[];

extern const uint64_t matmul_nvfp4_f16_dot2_f16acc_len;
extern const unsigned char matmul_nvfp4_f16_dot2_f16acc_data[];

extern const uint64_t matmul_nvfp4_f16_f16acc_len;
extern const unsigned char matmul_nvfp4_f16_f16acc_data[];

extern const uint64_t matmul_nvfp4_f16_f16acc_cm1_len;
extern const unsigned char matmul_nvfp4_f16_f16acc_cm1_data[];

extern const uint64_t matmul_nvfp4_f16_f16acc_cm2_len;
extern const unsigned char matmul_nvfp4_f16_f16acc_cm2_data[];

extern const uint64_t matmul_nvfp4_f16_fp32_len;
extern const unsigned char matmul_nvfp4_f16_fp32_data[];

extern const uint64_t matmul_nvfp4_f32_len;
extern const unsigned char matmul_nvfp4_f32_data[];

extern const uint64_t matmul_nvfp4_f32_cm1_len;
extern const unsigned char matmul_nvfp4_f32_cm1_data[];

extern const uint64_t matmul_nvfp4_f32_dot2_len;
extern const unsigned char matmul_nvfp4_f32_dot2_data[];

extern const uint64_t matmul_nvfp4_f32_dot2_f16acc_len;
extern const unsigned char matmul_nvfp4_f32_dot2_f16acc_data[];

extern const uint64_t matmul_nvfp4_f32_f16acc_len;
extern const unsigned char matmul_nvfp4_f32_f16acc_data[];

extern const uint64_t matmul_nvfp4_f32_f16acc_cm1_len;
extern const unsigned char matmul_nvfp4_f32_f16acc_cm1_data[];

extern const uint64_t matmul_nvfp4_f32_fp32_len;
extern const unsigned char matmul_nvfp4_f32_fp32_data[];

extern const uint64_t matmul_q1_0_f16_len;
extern const unsigned char matmul_q1_0_f16_data[];

extern const uint64_t matmul_q1_0_f16_cm1_len;
extern const unsigned char matmul_q1_0_f16_cm1_data[];

extern const uint64_t matmul_q1_0_f16_cm2_len;
extern const unsigned char matmul_q1_0_f16_cm2_data[];

extern const uint64_t matmul_q1_0_f16_dot2_len;
extern const unsigned char matmul_q1_0_f16_dot2_data[];

extern const uint64_t matmul_q1_0_f16_dot2_f16acc_len;
extern const unsigned char matmul_q1_0_f16_dot2_f16acc_data[];

extern const uint64_t matmul_q1_0_f16_f16acc_len;
extern const unsigned char matmul_q1_0_f16_f16acc_data[];

extern const uint64_t matmul_q1_0_f16_f16acc_cm1_len;
extern const unsigned char matmul_q1_0_f16_f16acc_cm1_data[];

extern const uint64_t matmul_q1_0_f16_f16acc_cm2_len;
extern const unsigned char matmul_q1_0_f16_f16acc_cm2_data[];

extern const uint64_t matmul_q1_0_f16_fp32_len;
extern const unsigned char matmul_q1_0_f16_fp32_data[];

extern const uint64_t matmul_q1_0_f32_len;
extern const unsigned char matmul_q1_0_f32_data[];

extern const uint64_t matmul_q1_0_f32_cm1_len;
extern const unsigned char matmul_q1_0_f32_cm1_data[];

extern const uint64_t matmul_q1_0_f32_dot2_len;
extern const unsigned char matmul_q1_0_f32_dot2_data[];

extern const uint64_t matmul_q1_0_f32_dot2_f16acc_len;
extern const unsigned char matmul_q1_0_f32_dot2_f16acc_data[];

extern const uint64_t matmul_q1_0_f32_f16acc_len;
extern const unsigned char matmul_q1_0_f32_f16acc_data[];

extern const uint64_t matmul_q1_0_f32_f16acc_cm1_len;
extern const unsigned char matmul_q1_0_f32_f16acc_cm1_data[];

extern const uint64_t matmul_q1_0_f32_fp32_len;
extern const unsigned char matmul_q1_0_f32_fp32_data[];

extern const uint64_t matmul_q2_k_f16_len;
extern const unsigned char matmul_q2_k_f16_data[];

extern const uint64_t matmul_q2_k_f16_cm1_len;
extern const unsigned char matmul_q2_k_f16_cm1_data[];

extern const uint64_t matmul_q2_k_f16_cm2_len;
extern const unsigned char matmul_q2_k_f16_cm2_data[];

extern const uint64_t matmul_q2_k_f16_dot2_len;
extern const unsigned char matmul_q2_k_f16_dot2_data[];

extern const uint64_t matmul_q2_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_q2_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_q2_k_f16_f16acc_len;
extern const unsigned char matmul_q2_k_f16_f16acc_data[];

extern const uint64_t matmul_q2_k_f16_f16acc_cm1_len;
extern const unsigned char matmul_q2_k_f16_f16acc_cm1_data[];

extern const uint64_t matmul_q2_k_f16_f16acc_cm2_len;
extern const unsigned char matmul_q2_k_f16_f16acc_cm2_data[];

extern const uint64_t matmul_q2_k_f16_fp32_len;
extern const unsigned char matmul_q2_k_f16_fp32_data[];

extern const uint64_t matmul_q2_k_f32_len;
extern const unsigned char matmul_q2_k_f32_data[];

extern const uint64_t matmul_q2_k_f32_cm1_len;
extern const unsigned char matmul_q2_k_f32_cm1_data[];

extern const uint64_t matmul_q2_k_f32_dot2_len;
extern const unsigned char matmul_q2_k_f32_dot2_data[];

extern const uint64_t matmul_q2_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_q2_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_q2_k_f32_f16acc_len;
extern const unsigned char matmul_q2_k_f32_f16acc_data[];

extern const uint64_t matmul_q2_k_f32_f16acc_cm1_len;
extern const unsigned char matmul_q2_k_f32_f16acc_cm1_data[];

extern const uint64_t matmul_q2_k_f32_fp32_len;
extern const unsigned char matmul_q2_k_f32_fp32_data[];

extern const uint64_t matmul_q2_k_q8_1_len;
extern const unsigned char matmul_q2_k_q8_1_data[];

extern const uint64_t matmul_q2_k_q8_1_fp32_len;
extern const unsigned char matmul_q2_k_q8_1_fp32_data[];

extern const uint64_t matmul_q3_k_f16_len;
extern const unsigned char matmul_q3_k_f16_data[];

extern const uint64_t matmul_q3_k_f16_cm1_len;
extern const unsigned char matmul_q3_k_f16_cm1_data[];

extern const uint64_t matmul_q3_k_f16_cm2_len;
extern const unsigned char matmul_q3_k_f16_cm2_data[];

extern const uint64_t matmul_q3_k_f16_dot2_len;
extern const unsigned char matmul_q3_k_f16_dot2_data[];

extern const uint64_t matmul_q3_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_q3_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_q3_k_f16_f16acc_len;
extern const unsigned char matmul_q3_k_f16_f16acc_data[];

extern const uint64_t matmul_q3_k_f16_f16acc_cm1_len;
extern const unsigned char matmul_q3_k_f16_f16acc_cm1_data[];

extern const uint64_t matmul_q3_k_f16_f16acc_cm2_len;
extern const unsigned char matmul_q3_k_f16_f16acc_cm2_data[];

extern const uint64_t matmul_q3_k_f16_fp32_len;
extern const unsigned char matmul_q3_k_f16_fp32_data[];

extern const uint64_t matmul_q3_k_f32_len;
extern const unsigned char matmul_q3_k_f32_data[];

extern const uint64_t matmul_q3_k_f32_cm1_len;
extern const unsigned char matmul_q3_k_f32_cm1_data[];

extern const uint64_t matmul_q3_k_f32_dot2_len;
extern const unsigned char matmul_q3_k_f32_dot2_data[];

extern const uint64_t matmul_q3_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_q3_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_q3_k_f32_f16acc_len;
extern const unsigned char matmul_q3_k_f32_f16acc_data[];

extern const uint64_t matmul_q3_k_f32_f16acc_cm1_len;
extern const unsigned char matmul_q3_k_f32_f16acc_cm1_data[];

extern const uint64_t matmul_q3_k_f32_fp32_len;
extern const unsigned char matmul_q3_k_f32_fp32_data[];

extern const uint64_t matmul_q3_k_q8_1_len;
extern const unsigned char matmul_q3_k_q8_1_data[];

extern const uint64_t matmul_q3_k_q8_1_fp32_len;
extern const unsigned char matmul_q3_k_q8_1_fp32_data[];

extern const uint64_t matmul_q4_0_f16_len;
extern const unsigned char matmul_q4_0_f16_data[];

extern const uint64_t matmul_q4_0_f16_cm1_len;
extern const unsigned char matmul_q4_0_f16_cm1_data[];

extern const uint64_t matmul_q4_0_f16_cm2_len;
extern const unsigned char matmul_q4_0_f16_cm2_data[];

extern const uint64_t matmul_q4_0_f16_dot2_len;
extern const unsigned char matmul_q4_0_f16_dot2_data[];

extern const uint64_t matmul_q4_0_f16_dot2_f16acc_len;
extern const unsigned char matmul_q4_0_f16_dot2_f16acc_data[];

extern const uint64_t matmul_q4_0_f16_f16acc_len;
extern const unsigned char matmul_q4_0_f16_f16acc_data[];

extern const uint64_t matmul_q4_0_f16_f16acc_cm1_len;
extern const unsigned char matmul_q4_0_f16_f16acc_cm1_data[];

extern const uint64_t matmul_q4_0_f16_f16acc_cm2_len;
extern const unsigned char matmul_q4_0_f16_f16acc_cm2_data[];

extern const uint64_t matmul_q4_0_f16_fp32_len;
extern const unsigned char matmul_q4_0_f16_fp32_data[];

extern const uint64_t matmul_q4_0_f32_len;
extern const unsigned char matmul_q4_0_f32_data[];

extern const uint64_t matmul_q4_0_f32_cm1_len;
extern const unsigned char matmul_q4_0_f32_cm1_data[];

extern const uint64_t matmul_q4_0_f32_dot2_len;
extern const unsigned char matmul_q4_0_f32_dot2_data[];

extern const uint64_t matmul_q4_0_f32_dot2_f16acc_len;
extern const unsigned char matmul_q4_0_f32_dot2_f16acc_data[];

extern const uint64_t matmul_q4_0_f32_f16acc_len;
extern const unsigned char matmul_q4_0_f32_f16acc_data[];

extern const uint64_t matmul_q4_0_f32_f16acc_cm1_len;
extern const unsigned char matmul_q4_0_f32_f16acc_cm1_data[];

extern const uint64_t matmul_q4_0_f32_fp32_len;
extern const unsigned char matmul_q4_0_f32_fp32_data[];

extern const uint64_t matmul_q4_0_q8_1_len;
extern const unsigned char matmul_q4_0_q8_1_data[];

extern const uint64_t matmul_q4_0_q8_1_fp32_len;
extern const unsigned char matmul_q4_0_q8_1_fp32_data[];

extern const uint64_t matmul_q4_1_f16_len;
extern const unsigned char matmul_q4_1_f16_data[];

extern const uint64_t matmul_q4_1_f16_cm1_len;
extern const unsigned char matmul_q4_1_f16_cm1_data[];

extern const uint64_t matmul_q4_1_f16_cm2_len;
extern const unsigned char matmul_q4_1_f16_cm2_data[];

extern const uint64_t matmul_q4_1_f16_dot2_len;
extern const unsigned char matmul_q4_1_f16_dot2_data[];

extern const uint64_t matmul_q4_1_f16_dot2_f16acc_len;
extern const unsigned char matmul_q4_1_f16_dot2_f16acc_data[];

extern const uint64_t matmul_q4_1_f16_f16acc_len;
extern const unsigned char matmul_q4_1_f16_f16acc_data[];

extern const uint64_t matmul_q4_1_f16_f16acc_cm1_len;
extern const unsigned char matmul_q4_1_f16_f16acc_cm1_data[];

extern const uint64_t matmul_q4_1_f16_f16acc_cm2_len;
extern const unsigned char matmul_q4_1_f16_f16acc_cm2_data[];

extern const uint64_t matmul_q4_1_f16_fp32_len;
extern const unsigned char matmul_q4_1_f16_fp32_data[];

extern const uint64_t matmul_q4_1_f32_len;
extern const unsigned char matmul_q4_1_f32_data[];

extern const uint64_t matmul_q4_1_f32_cm1_len;
extern const unsigned char matmul_q4_1_f32_cm1_data[];

extern const uint64_t matmul_q4_1_f32_dot2_len;
extern const unsigned char matmul_q4_1_f32_dot2_data[];

extern const uint64_t matmul_q4_1_f32_dot2_f16acc_len;
extern const unsigned char matmul_q4_1_f32_dot2_f16acc_data[];

extern const uint64_t matmul_q4_1_f32_f16acc_len;
extern const unsigned char matmul_q4_1_f32_f16acc_data[];

extern const uint64_t matmul_q4_1_f32_f16acc_cm1_len;
extern const unsigned char matmul_q4_1_f32_f16acc_cm1_data[];

extern const uint64_t matmul_q4_1_f32_fp32_len;
extern const unsigned char matmul_q4_1_f32_fp32_data[];

extern const uint64_t matmul_q4_1_q8_1_len;
extern const unsigned char matmul_q4_1_q8_1_data[];

extern const uint64_t matmul_q4_1_q8_1_fp32_len;
extern const unsigned char matmul_q4_1_q8_1_fp32_data[];

extern const uint64_t matmul_q4_k_f16_len;
extern const unsigned char matmul_q4_k_f16_data[];

extern const uint64_t matmul_q4_k_f16_cm1_len;
extern const unsigned char matmul_q4_k_f16_cm1_data[];

extern const uint64_t matmul_q4_k_f16_cm2_len;
extern const unsigned char matmul_q4_k_f16_cm2_data[];

extern const uint64_t matmul_q4_k_f16_dot2_len;
extern const unsigned char matmul_q4_k_f16_dot2_data[];

extern const uint64_t matmul_q4_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_q4_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_q4_k_f16_f16acc_len;
extern const unsigned char matmul_q4_k_f16_f16acc_data[];

extern const uint64_t matmul_q4_k_f16_f16acc_cm1_len;
extern const unsigned char matmul_q4_k_f16_f16acc_cm1_data[];

extern const uint64_t matmul_q4_k_f16_f16acc_cm2_len;
extern const unsigned char matmul_q4_k_f16_f16acc_cm2_data[];

extern const uint64_t matmul_q4_k_f16_fp32_len;
extern const unsigned char matmul_q4_k_f16_fp32_data[];

extern const uint64_t matmul_q4_k_f32_len;
extern const unsigned char matmul_q4_k_f32_data[];

extern const uint64_t matmul_q4_k_f32_cm1_len;
extern const unsigned char matmul_q4_k_f32_cm1_data[];

extern const uint64_t matmul_q4_k_f32_dot2_len;
extern const unsigned char matmul_q4_k_f32_dot2_data[];

extern const uint64_t matmul_q4_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_q4_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_q4_k_f32_f16acc_len;
extern const unsigned char matmul_q4_k_f32_f16acc_data[];

extern const uint64_t matmul_q4_k_f32_f16acc_cm1_len;
extern const unsigned char matmul_q4_k_f32_f16acc_cm1_data[];

extern const uint64_t matmul_q4_k_f32_fp32_len;
extern const unsigned char matmul_q4_k_f32_fp32_data[];

extern const uint64_t matmul_q4_k_q8_1_len;
extern const unsigned char matmul_q4_k_q8_1_data[];

extern const uint64_t matmul_q4_k_q8_1_fp32_len;
extern const unsigned char matmul_q4_k_q8_1_fp32_data[];

extern const uint64_t matmul_q5_0_f16_len;
extern const unsigned char matmul_q5_0_f16_data[];

extern const uint64_t matmul_q5_0_f16_cm1_len;
extern const unsigned char matmul_q5_0_f16_cm1_data[];

extern const uint64_t matmul_q5_0_f16_cm2_len;
extern const unsigned char matmul_q5_0_f16_cm2_data[];

extern const uint64_t matmul_q5_0_f16_dot2_len;
extern const unsigned char matmul_q5_0_f16_dot2_data[];

extern const uint64_t matmul_q5_0_f16_dot2_f16acc_len;
extern const unsigned char matmul_q5_0_f16_dot2_f16acc_data[];

extern const uint64_t matmul_q5_0_f16_f16acc_len;
extern const unsigned char matmul_q5_0_f16_f16acc_data[];

extern const uint64_t matmul_q5_0_f16_f16acc_cm1_len;
extern const unsigned char matmul_q5_0_f16_f16acc_cm1_data[];

extern const uint64_t matmul_q5_0_f16_f16acc_cm2_len;
extern const unsigned char matmul_q5_0_f16_f16acc_cm2_data[];

extern const uint64_t matmul_q5_0_f16_fp32_len;
extern const unsigned char matmul_q5_0_f16_fp32_data[];

extern const uint64_t matmul_q5_0_f32_len;
extern const unsigned char matmul_q5_0_f32_data[];

extern const uint64_t matmul_q5_0_f32_cm1_len;
extern const unsigned char matmul_q5_0_f32_cm1_data[];

extern const uint64_t matmul_q5_0_f32_dot2_len;
extern const unsigned char matmul_q5_0_f32_dot2_data[];

extern const uint64_t matmul_q5_0_f32_dot2_f16acc_len;
extern const unsigned char matmul_q5_0_f32_dot2_f16acc_data[];

extern const uint64_t matmul_q5_0_f32_f16acc_len;
extern const unsigned char matmul_q5_0_f32_f16acc_data[];

extern const uint64_t matmul_q5_0_f32_f16acc_cm1_len;
extern const unsigned char matmul_q5_0_f32_f16acc_cm1_data[];

extern const uint64_t matmul_q5_0_f32_fp32_len;
extern const unsigned char matmul_q5_0_f32_fp32_data[];

extern const uint64_t matmul_q5_0_q8_1_len;
extern const unsigned char matmul_q5_0_q8_1_data[];

extern const uint64_t matmul_q5_0_q8_1_fp32_len;
extern const unsigned char matmul_q5_0_q8_1_fp32_data[];

extern const uint64_t matmul_q5_1_f16_len;
extern const unsigned char matmul_q5_1_f16_data[];

extern const uint64_t matmul_q5_1_f16_cm1_len;
extern const unsigned char matmul_q5_1_f16_cm1_data[];

extern const uint64_t matmul_q5_1_f16_cm2_len;
extern const unsigned char matmul_q5_1_f16_cm2_data[];

extern const uint64_t matmul_q5_1_f16_dot2_len;
extern const unsigned char matmul_q5_1_f16_dot2_data[];

extern const uint64_t matmul_q5_1_f16_dot2_f16acc_len;
extern const unsigned char matmul_q5_1_f16_dot2_f16acc_data[];

extern const uint64_t matmul_q5_1_f16_f16acc_len;
extern const unsigned char matmul_q5_1_f16_f16acc_data[];

extern const uint64_t matmul_q5_1_f16_f16acc_cm1_len;
extern const unsigned char matmul_q5_1_f16_f16acc_cm1_data[];

extern const uint64_t matmul_q5_1_f16_f16acc_cm2_len;
extern const unsigned char matmul_q5_1_f16_f16acc_cm2_data[];

extern const uint64_t matmul_q5_1_f16_fp32_len;
extern const unsigned char matmul_q5_1_f16_fp32_data[];

extern const uint64_t matmul_q5_1_f32_len;
extern const unsigned char matmul_q5_1_f32_data[];

extern const uint64_t matmul_q5_1_f32_cm1_len;
extern const unsigned char matmul_q5_1_f32_cm1_data[];

extern const uint64_t matmul_q5_1_f32_dot2_len;
extern const unsigned char matmul_q5_1_f32_dot2_data[];

extern const uint64_t matmul_q5_1_f32_dot2_f16acc_len;
extern const unsigned char matmul_q5_1_f32_dot2_f16acc_data[];

extern const uint64_t matmul_q5_1_f32_f16acc_len;
extern const unsigned char matmul_q5_1_f32_f16acc_data[];

extern const uint64_t matmul_q5_1_f32_f16acc_cm1_len;
extern const unsigned char matmul_q5_1_f32_f16acc_cm1_data[];

extern const uint64_t matmul_q5_1_f32_fp32_len;
extern const unsigned char matmul_q5_1_f32_fp32_data[];

extern const uint64_t matmul_q5_1_q8_1_len;
extern const unsigned char matmul_q5_1_q8_1_data[];

extern const uint64_t matmul_q5_1_q8_1_fp32_len;
extern const unsigned char matmul_q5_1_q8_1_fp32_data[];

extern const uint64_t matmul_q5_k_f16_len;
extern const unsigned char matmul_q5_k_f16_data[];

extern const uint64_t matmul_q5_k_f16_cm1_len;
extern const unsigned char matmul_q5_k_f16_cm1_data[];

extern const uint64_t matmul_q5_k_f16_cm2_len;
extern const unsigned char matmul_q5_k_f16_cm2_data[];

extern const uint64_t matmul_q5_k_f16_dot2_len;
extern const unsigned char matmul_q5_k_f16_dot2_data[];

extern const uint64_t matmul_q5_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_q5_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_q5_k_f16_f16acc_len;
extern const unsigned char matmul_q5_k_f16_f16acc_data[];

extern const uint64_t matmul_q5_k_f16_f16acc_cm1_len;
extern const unsigned char matmul_q5_k_f16_f16acc_cm1_data[];

extern const uint64_t matmul_q5_k_f16_f16acc_cm2_len;
extern const unsigned char matmul_q5_k_f16_f16acc_cm2_data[];

extern const uint64_t matmul_q5_k_f16_fp32_len;
extern const unsigned char matmul_q5_k_f16_fp32_data[];

extern const uint64_t matmul_q5_k_f32_len;
extern const unsigned char matmul_q5_k_f32_data[];

extern const uint64_t matmul_q5_k_f32_cm1_len;
extern const unsigned char matmul_q5_k_f32_cm1_data[];

extern const uint64_t matmul_q5_k_f32_dot2_len;
extern const unsigned char matmul_q5_k_f32_dot2_data[];

extern const uint64_t matmul_q5_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_q5_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_q5_k_f32_f16acc_len;
extern const unsigned char matmul_q5_k_f32_f16acc_data[];

extern const uint64_t matmul_q5_k_f32_f16acc_cm1_len;
extern const unsigned char matmul_q5_k_f32_f16acc_cm1_data[];

extern const uint64_t matmul_q5_k_f32_fp32_len;
extern const unsigned char matmul_q5_k_f32_fp32_data[];

extern const uint64_t matmul_q5_k_q8_1_len;
extern const unsigned char matmul_q5_k_q8_1_data[];

extern const uint64_t matmul_q5_k_q8_1_fp32_len;
extern const unsigned char matmul_q5_k_q8_1_fp32_data[];

extern const uint64_t matmul_q6_k_f16_len;
extern const unsigned char matmul_q6_k_f16_data[];

extern const uint64_t matmul_q6_k_f16_cm1_len;
extern const unsigned char matmul_q6_k_f16_cm1_data[];

extern const uint64_t matmul_q6_k_f16_cm2_len;
extern const unsigned char matmul_q6_k_f16_cm2_data[];

extern const uint64_t matmul_q6_k_f16_dot2_len;
extern const unsigned char matmul_q6_k_f16_dot2_data[];

extern const uint64_t matmul_q6_k_f16_dot2_f16acc_len;
extern const unsigned char matmul_q6_k_f16_dot2_f16acc_data[];

extern const uint64_t matmul_q6_k_f16_f16acc_len;
extern const unsigned char matmul_q6_k_f16_f16acc_data[];

extern const uint64_t matmul_q6_k_f16_f16acc_cm1_len;
extern const unsigned char matmul_q6_k_f16_f16acc_cm1_data[];

extern const uint64_t matmul_q6_k_f16_f16acc_cm2_len;
extern const unsigned char matmul_q6_k_f16_f16acc_cm2_data[];

extern const uint64_t matmul_q6_k_f16_fp32_len;
extern const unsigned char matmul_q6_k_f16_fp32_data[];

extern const uint64_t matmul_q6_k_f32_len;
extern const unsigned char matmul_q6_k_f32_data[];

extern const uint64_t matmul_q6_k_f32_cm1_len;
extern const unsigned char matmul_q6_k_f32_cm1_data[];

extern const uint64_t matmul_q6_k_f32_dot2_len;
extern const unsigned char matmul_q6_k_f32_dot2_data[];

extern const uint64_t matmul_q6_k_f32_dot2_f16acc_len;
extern const unsigned char matmul_q6_k_f32_dot2_f16acc_data[];

extern const uint64_t matmul_q6_k_f32_f16acc_len;
extern const unsigned char matmul_q6_k_f32_f16acc_data[];

extern const uint64_t matmul_q6_k_f32_f16acc_cm1_len;
extern const unsigned char matmul_q6_k_f32_f16acc_cm1_data[];

extern const uint64_t matmul_q6_k_f32_fp32_len;
extern const unsigned char matmul_q6_k_f32_fp32_data[];

extern const uint64_t matmul_q6_k_q8_1_len;
extern const unsigned char matmul_q6_k_q8_1_data[];

extern const uint64_t matmul_q6_k_q8_1_fp32_len;
extern const unsigned char matmul_q6_k_q8_1_fp32_data[];

extern const uint64_t matmul_q8_0_f16_len;
extern const unsigned char matmul_q8_0_f16_data[];

extern const uint64_t matmul_q8_0_f16_cm1_len;
extern const unsigned char matmul_q8_0_f16_cm1_data[];

extern const uint64_t matmul_q8_0_f16_cm2_len;
extern const unsigned char matmul_q8_0_f16_cm2_data[];

extern const uint64_t matmul_q8_0_f16_dot2_len;
extern const unsigned char matmul_q8_0_f16_dot2_data[];

extern const uint64_t matmul_q8_0_f16_dot2_f16acc_len;
extern const unsigned char matmul_q8_0_f16_dot2_f16acc_data[];

extern const uint64_t matmul_q8_0_f16_f16acc_len;
extern const unsigned char matmul_q8_0_f16_f16acc_data[];

extern const uint64_t matmul_q8_0_f16_f16acc_cm1_len;
extern const unsigned char matmul_q8_0_f16_f16acc_cm1_data[];

extern const uint64_t matmul_q8_0_f16_f16acc_cm2_len;
extern const unsigned char matmul_q8_0_f16_f16acc_cm2_data[];

extern const uint64_t matmul_q8_0_f16_fp32_len;
extern const unsigned char matmul_q8_0_f16_fp32_data[];

extern const uint64_t matmul_q8_0_f32_len;
extern const unsigned char matmul_q8_0_f32_data[];

extern const uint64_t matmul_q8_0_f32_cm1_len;
extern const unsigned char matmul_q8_0_f32_cm1_data[];

extern const uint64_t matmul_q8_0_f32_dot2_len;
extern const unsigned char matmul_q8_0_f32_dot2_data[];

extern const uint64_t matmul_q8_0_f32_dot2_f16acc_len;
extern const unsigned char matmul_q8_0_f32_dot2_f16acc_data[];

extern const uint64_t matmul_q8_0_f32_f16acc_len;
extern const unsigned char matmul_q8_0_f32_f16acc_data[];

extern const uint64_t matmul_q8_0_f32_f16acc_cm1_len;
extern const unsigned char matmul_q8_0_f32_f16acc_cm1_data[];

extern const uint64_t matmul_q8_0_f32_fp32_len;
extern const unsigned char matmul_q8_0_f32_fp32_data[];

extern const uint64_t matmul_q8_0_q8_1_len;
extern const unsigned char matmul_q8_0_q8_1_data[];

extern const uint64_t matmul_q8_0_q8_1_fp32_len;
extern const unsigned char matmul_q8_0_q8_1_fp32_data[];

extern const uint64_t mul_f16_f16_f16_len;
extern const unsigned char mul_f16_f16_f16_data[];

extern const uint64_t mul_f16_f16_f32_len;
extern const unsigned char mul_f16_f16_f32_data[];

extern const uint64_t mul_f16_f32_f16_len;
extern const unsigned char mul_f16_f32_f16_data[];

extern const uint64_t mul_f16_f32_f32_len;
extern const unsigned char mul_f16_f32_f32_data[];

extern const uint64_t mul_f32_len;
extern const unsigned char mul_f32_data[];

extern const uint64_t mul_f32_f16_f16_len;
extern const unsigned char mul_f32_f16_f16_data[];

extern const uint64_t mul_f32_f16_f32_len;
extern const unsigned char mul_f32_f16_f32_data[];

extern const uint64_t mul_f32_f32_f16_len;
extern const unsigned char mul_f32_f32_f16_data[];

extern const uint64_t mul_f32_f32_f32_len;
extern const unsigned char mul_f32_f32_f32_data[];

extern const uint64_t mul_mat_vec_bf16_f16_f32_len;
extern const unsigned char mul_mat_vec_bf16_f16_f32_data[];

extern const uint64_t mul_mat_vec_bf16_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_bf16_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_bf16_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_bf16_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_bf16_f32_f32_len;
extern const unsigned char mul_mat_vec_bf16_f32_f32_data[];

extern const uint64_t mul_mat_vec_bf16_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_bf16_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_bf16_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_bf16_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_f16_f16_f32_len;
extern const unsigned char mul_mat_vec_f16_f16_f32_data[];

extern const uint64_t mul_mat_vec_f16_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_f16_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_f16_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_f16_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_f16_f32_f32_len;
extern const unsigned char mul_mat_vec_f16_f32_f32_data[];

extern const uint64_t mul_mat_vec_f16_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_f16_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_f16_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_f16_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_f32_f16_f32_len;
extern const unsigned char mul_mat_vec_f32_f16_f32_data[];

extern const uint64_t mul_mat_vec_f32_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_f32_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_f32_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_f32_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_f32_f32_f32_len;
extern const unsigned char mul_mat_vec_f32_f32_f32_data[];

extern const uint64_t mul_mat_vec_f32_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_f32_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_f32_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_f32_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_bf16_f32_f32_len;
extern const unsigned char mul_mat_vec_id_bf16_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_bf16_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_bf16_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_bf16_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_bf16_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_f16_f32_f32_len;
extern const unsigned char mul_mat_vec_id_f16_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_f16_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_f16_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_f16_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_f16_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_f32_f32_f32_len;
extern const unsigned char mul_mat_vec_id_f32_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_f32_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_f32_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_f32_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_f32_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_iq1_m_f32_f32_len;
extern const unsigned char mul_mat_vec_id_iq1_m_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_iq1_m_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_iq1_m_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_iq1_m_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_iq1_m_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_iq1_m_q8_1_f32_len;
extern const unsigned char mul_mat_vec_id_iq1_m_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_id_iq1_m_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_iq1_m_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_iq1_m_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_iq1_m_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_iq1_s_f32_f32_len;
extern const unsigned char mul_mat_vec_id_iq1_s_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_iq1_s_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_iq1_s_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_iq1_s_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_iq1_s_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_iq1_s_q8_1_f32_len;
extern const unsigned char mul_mat_vec_id_iq1_s_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_id_iq1_s_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_iq1_s_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_iq1_s_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_iq1_s_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_iq2_s_f32_f32_len;
extern const unsigned char mul_mat_vec_id_iq2_s_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_iq2_s_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_iq2_s_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_iq2_s_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_iq2_s_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_iq2_xs_f32_f32_len;
extern const unsigned char mul_mat_vec_id_iq2_xs_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_iq2_xs_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_iq2_xs_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_iq2_xs_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_iq2_xs_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_iq2_xxs_f32_f32_len;
extern const unsigned char mul_mat_vec_id_iq2_xxs_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_iq2_xxs_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_iq2_xxs_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_iq2_xxs_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_iq2_xxs_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_iq3_s_f32_f32_len;
extern const unsigned char mul_mat_vec_id_iq3_s_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_iq3_s_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_iq3_s_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_iq3_s_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_iq3_s_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_iq3_xxs_f32_f32_len;
extern const unsigned char mul_mat_vec_id_iq3_xxs_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_iq3_xxs_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_iq3_xxs_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_iq3_xxs_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_iq3_xxs_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_iq4_nl_f32_f32_len;
extern const unsigned char mul_mat_vec_id_iq4_nl_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_iq4_nl_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_iq4_nl_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_iq4_nl_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_iq4_nl_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_iq4_xs_f32_f32_len;
extern const unsigned char mul_mat_vec_id_iq4_xs_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_iq4_xs_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_iq4_xs_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_iq4_xs_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_iq4_xs_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_mxfp4_f32_f32_len;
extern const unsigned char mul_mat_vec_id_mxfp4_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_mxfp4_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_mxfp4_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_mxfp4_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_mxfp4_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_mxfp4_q8_1_f32_len;
extern const unsigned char mul_mat_vec_id_mxfp4_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_id_mxfp4_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_mxfp4_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_mxfp4_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_mxfp4_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_nvfp4_f32_f32_len;
extern const unsigned char mul_mat_vec_id_nvfp4_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_nvfp4_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_nvfp4_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_nvfp4_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_nvfp4_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q1_0_f32_f32_len;
extern const unsigned char mul_mat_vec_id_q1_0_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_q1_0_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q1_0_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q1_0_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q1_0_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q2_k_f32_f32_len;
extern const unsigned char mul_mat_vec_id_q2_k_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_q2_k_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q2_k_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q2_k_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q2_k_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q2_k_q8_1_f32_len;
extern const unsigned char mul_mat_vec_id_q2_k_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_id_q2_k_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q2_k_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q2_k_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q2_k_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q3_k_f32_f32_len;
extern const unsigned char mul_mat_vec_id_q3_k_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_q3_k_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q3_k_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q3_k_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q3_k_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q3_k_q8_1_f32_len;
extern const unsigned char mul_mat_vec_id_q3_k_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_id_q3_k_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q3_k_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q3_k_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q3_k_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q4_0_f32_f32_len;
extern const unsigned char mul_mat_vec_id_q4_0_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_q4_0_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q4_0_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q4_0_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q4_0_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q4_0_q8_1_f32_len;
extern const unsigned char mul_mat_vec_id_q4_0_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_id_q4_0_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q4_0_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q4_0_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q4_0_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q4_1_f32_f32_len;
extern const unsigned char mul_mat_vec_id_q4_1_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_q4_1_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q4_1_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q4_1_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q4_1_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q4_1_q8_1_f32_len;
extern const unsigned char mul_mat_vec_id_q4_1_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_id_q4_1_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q4_1_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q4_1_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q4_1_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q4_k_f32_f32_len;
extern const unsigned char mul_mat_vec_id_q4_k_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_q4_k_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q4_k_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q4_k_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q4_k_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q4_k_q8_1_f32_len;
extern const unsigned char mul_mat_vec_id_q4_k_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_id_q4_k_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q4_k_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q4_k_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q4_k_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q5_0_f32_f32_len;
extern const unsigned char mul_mat_vec_id_q5_0_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_q5_0_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q5_0_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q5_0_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q5_0_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q5_0_q8_1_f32_len;
extern const unsigned char mul_mat_vec_id_q5_0_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_id_q5_0_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q5_0_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q5_0_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q5_0_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q5_1_f32_f32_len;
extern const unsigned char mul_mat_vec_id_q5_1_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_q5_1_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q5_1_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q5_1_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q5_1_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q5_1_q8_1_f32_len;
extern const unsigned char mul_mat_vec_id_q5_1_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_id_q5_1_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q5_1_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q5_1_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q5_1_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q5_k_f32_f32_len;
extern const unsigned char mul_mat_vec_id_q5_k_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_q5_k_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q5_k_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q5_k_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q5_k_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q5_k_q8_1_f32_len;
extern const unsigned char mul_mat_vec_id_q5_k_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_id_q5_k_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q5_k_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q5_k_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q5_k_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q6_k_f32_f32_len;
extern const unsigned char mul_mat_vec_id_q6_k_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_q6_k_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q6_k_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q6_k_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q6_k_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q6_k_q8_1_f32_len;
extern const unsigned char mul_mat_vec_id_q6_k_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_id_q6_k_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q6_k_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q6_k_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q6_k_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q8_0_f32_f32_len;
extern const unsigned char mul_mat_vec_id_q8_0_f32_f32_data[];

extern const uint64_t mul_mat_vec_id_q8_0_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q8_0_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q8_0_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q8_0_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_id_q8_0_q8_1_f32_len;
extern const unsigned char mul_mat_vec_id_q8_0_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_id_q8_0_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_id_q8_0_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_id_q8_0_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_id_q8_0_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq1_m_f16_f32_len;
extern const unsigned char mul_mat_vec_iq1_m_f16_f32_data[];

extern const uint64_t mul_mat_vec_iq1_m_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq1_m_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq1_m_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq1_m_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq1_m_f32_f32_len;
extern const unsigned char mul_mat_vec_iq1_m_f32_f32_data[];

extern const uint64_t mul_mat_vec_iq1_m_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq1_m_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq1_m_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq1_m_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq1_m_q8_1_f32_len;
extern const unsigned char mul_mat_vec_iq1_m_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_iq1_m_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq1_m_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq1_m_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq1_m_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq1_s_f16_f32_len;
extern const unsigned char mul_mat_vec_iq1_s_f16_f32_data[];

extern const uint64_t mul_mat_vec_iq1_s_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq1_s_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq1_s_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq1_s_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq1_s_f32_f32_len;
extern const unsigned char mul_mat_vec_iq1_s_f32_f32_data[];

extern const uint64_t mul_mat_vec_iq1_s_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq1_s_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq1_s_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq1_s_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq1_s_q8_1_f32_len;
extern const unsigned char mul_mat_vec_iq1_s_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_iq1_s_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq1_s_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq1_s_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq1_s_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq2_s_f16_f32_len;
extern const unsigned char mul_mat_vec_iq2_s_f16_f32_data[];

extern const uint64_t mul_mat_vec_iq2_s_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq2_s_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq2_s_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq2_s_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq2_s_f32_f32_len;
extern const unsigned char mul_mat_vec_iq2_s_f32_f32_data[];

extern const uint64_t mul_mat_vec_iq2_s_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq2_s_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq2_s_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq2_s_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq2_xs_f16_f32_len;
extern const unsigned char mul_mat_vec_iq2_xs_f16_f32_data[];

extern const uint64_t mul_mat_vec_iq2_xs_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq2_xs_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq2_xs_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq2_xs_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq2_xs_f32_f32_len;
extern const unsigned char mul_mat_vec_iq2_xs_f32_f32_data[];

extern const uint64_t mul_mat_vec_iq2_xs_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq2_xs_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq2_xs_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq2_xs_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq2_xxs_f16_f32_len;
extern const unsigned char mul_mat_vec_iq2_xxs_f16_f32_data[];

extern const uint64_t mul_mat_vec_iq2_xxs_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq2_xxs_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq2_xxs_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq2_xxs_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq2_xxs_f32_f32_len;
extern const unsigned char mul_mat_vec_iq2_xxs_f32_f32_data[];

extern const uint64_t mul_mat_vec_iq2_xxs_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq2_xxs_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq2_xxs_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq2_xxs_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq3_s_f16_f32_len;
extern const unsigned char mul_mat_vec_iq3_s_f16_f32_data[];

extern const uint64_t mul_mat_vec_iq3_s_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq3_s_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq3_s_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq3_s_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq3_s_f32_f32_len;
extern const unsigned char mul_mat_vec_iq3_s_f32_f32_data[];

extern const uint64_t mul_mat_vec_iq3_s_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq3_s_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq3_s_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq3_s_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq3_xxs_f16_f32_len;
extern const unsigned char mul_mat_vec_iq3_xxs_f16_f32_data[];

extern const uint64_t mul_mat_vec_iq3_xxs_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq3_xxs_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq3_xxs_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq3_xxs_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq3_xxs_f32_f32_len;
extern const unsigned char mul_mat_vec_iq3_xxs_f32_f32_data[];

extern const uint64_t mul_mat_vec_iq3_xxs_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq3_xxs_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq3_xxs_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq3_xxs_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq4_nl_f16_f32_len;
extern const unsigned char mul_mat_vec_iq4_nl_f16_f32_data[];

extern const uint64_t mul_mat_vec_iq4_nl_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq4_nl_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq4_nl_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq4_nl_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq4_nl_f32_f32_len;
extern const unsigned char mul_mat_vec_iq4_nl_f32_f32_data[];

extern const uint64_t mul_mat_vec_iq4_nl_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq4_nl_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq4_nl_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq4_nl_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq4_xs_f16_f32_len;
extern const unsigned char mul_mat_vec_iq4_xs_f16_f32_data[];

extern const uint64_t mul_mat_vec_iq4_xs_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq4_xs_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq4_xs_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq4_xs_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_iq4_xs_f32_f32_len;
extern const unsigned char mul_mat_vec_iq4_xs_f32_f32_data[];

extern const uint64_t mul_mat_vec_iq4_xs_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_iq4_xs_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_iq4_xs_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_iq4_xs_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_mxfp4_f16_f32_len;
extern const unsigned char mul_mat_vec_mxfp4_f16_f32_data[];

extern const uint64_t mul_mat_vec_mxfp4_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_mxfp4_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_mxfp4_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_mxfp4_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_mxfp4_f32_f32_len;
extern const unsigned char mul_mat_vec_mxfp4_f32_f32_data[];

extern const uint64_t mul_mat_vec_mxfp4_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_mxfp4_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_mxfp4_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_mxfp4_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_mxfp4_q8_1_f32_len;
extern const unsigned char mul_mat_vec_mxfp4_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_mxfp4_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_mxfp4_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_mxfp4_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_mxfp4_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_nc_f16_f32_len;
extern const unsigned char mul_mat_vec_nc_f16_f32_data[];

extern const uint64_t mul_mat_vec_nvfp4_f16_f32_len;
extern const unsigned char mul_mat_vec_nvfp4_f16_f32_data[];

extern const uint64_t mul_mat_vec_nvfp4_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_nvfp4_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_nvfp4_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_nvfp4_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_nvfp4_f32_f32_len;
extern const unsigned char mul_mat_vec_nvfp4_f32_f32_data[];

extern const uint64_t mul_mat_vec_nvfp4_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_nvfp4_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_nvfp4_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_nvfp4_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_p021_f16_f32_len;
extern const unsigned char mul_mat_vec_p021_f16_f32_data[];

extern const uint64_t mul_mat_vec_p021_f16_f32_subgroup_add_len;
extern const unsigned char mul_mat_vec_p021_f16_f32_subgroup_add_data[];

extern const uint64_t mul_mat_vec_q1_0_f16_f32_len;
extern const unsigned char mul_mat_vec_q1_0_f16_f32_data[];

extern const uint64_t mul_mat_vec_q1_0_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q1_0_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q1_0_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q1_0_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q1_0_f32_f32_len;
extern const unsigned char mul_mat_vec_q1_0_f32_f32_data[];

extern const uint64_t mul_mat_vec_q1_0_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q1_0_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q1_0_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q1_0_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q2_k_f16_f32_len;
extern const unsigned char mul_mat_vec_q2_k_f16_f32_data[];

extern const uint64_t mul_mat_vec_q2_k_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q2_k_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q2_k_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q2_k_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q2_k_f32_f32_len;
extern const unsigned char mul_mat_vec_q2_k_f32_f32_data[];

extern const uint64_t mul_mat_vec_q2_k_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q2_k_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q2_k_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q2_k_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q2_k_q8_1_f32_len;
extern const unsigned char mul_mat_vec_q2_k_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_q2_k_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q2_k_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q2_k_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q2_k_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q3_k_f16_f32_len;
extern const unsigned char mul_mat_vec_q3_k_f16_f32_data[];

extern const uint64_t mul_mat_vec_q3_k_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q3_k_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q3_k_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q3_k_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q3_k_f32_f32_len;
extern const unsigned char mul_mat_vec_q3_k_f32_f32_data[];

extern const uint64_t mul_mat_vec_q3_k_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q3_k_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q3_k_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q3_k_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q3_k_q8_1_f32_len;
extern const unsigned char mul_mat_vec_q3_k_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_q3_k_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q3_k_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q3_k_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q3_k_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q4_0_f16_f32_len;
extern const unsigned char mul_mat_vec_q4_0_f16_f32_data[];

extern const uint64_t mul_mat_vec_q4_0_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q4_0_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q4_0_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q4_0_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q4_0_f32_f32_len;
extern const unsigned char mul_mat_vec_q4_0_f32_f32_data[];

extern const uint64_t mul_mat_vec_q4_0_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q4_0_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q4_0_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q4_0_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q4_0_q8_1_f32_len;
extern const unsigned char mul_mat_vec_q4_0_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_q4_0_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q4_0_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q4_0_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q4_0_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q4_1_f16_f32_len;
extern const unsigned char mul_mat_vec_q4_1_f16_f32_data[];

extern const uint64_t mul_mat_vec_q4_1_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q4_1_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q4_1_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q4_1_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q4_1_f32_f32_len;
extern const unsigned char mul_mat_vec_q4_1_f32_f32_data[];

extern const uint64_t mul_mat_vec_q4_1_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q4_1_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q4_1_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q4_1_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q4_1_q8_1_f32_len;
extern const unsigned char mul_mat_vec_q4_1_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_q4_1_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q4_1_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q4_1_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q4_1_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q4_k_f16_f32_len;
extern const unsigned char mul_mat_vec_q4_k_f16_f32_data[];

extern const uint64_t mul_mat_vec_q4_k_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q4_k_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q4_k_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q4_k_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q4_k_f32_f32_len;
extern const unsigned char mul_mat_vec_q4_k_f32_f32_data[];

extern const uint64_t mul_mat_vec_q4_k_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q4_k_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q4_k_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q4_k_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q4_k_q8_1_f32_len;
extern const unsigned char mul_mat_vec_q4_k_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_q4_k_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q4_k_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q4_k_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q4_k_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q5_0_f16_f32_len;
extern const unsigned char mul_mat_vec_q5_0_f16_f32_data[];

extern const uint64_t mul_mat_vec_q5_0_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q5_0_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q5_0_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q5_0_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q5_0_f32_f32_len;
extern const unsigned char mul_mat_vec_q5_0_f32_f32_data[];

extern const uint64_t mul_mat_vec_q5_0_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q5_0_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q5_0_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q5_0_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q5_0_q8_1_f32_len;
extern const unsigned char mul_mat_vec_q5_0_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_q5_0_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q5_0_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q5_0_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q5_0_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q5_1_f16_f32_len;
extern const unsigned char mul_mat_vec_q5_1_f16_f32_data[];

extern const uint64_t mul_mat_vec_q5_1_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q5_1_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q5_1_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q5_1_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q5_1_f32_f32_len;
extern const unsigned char mul_mat_vec_q5_1_f32_f32_data[];

extern const uint64_t mul_mat_vec_q5_1_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q5_1_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q5_1_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q5_1_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q5_1_q8_1_f32_len;
extern const unsigned char mul_mat_vec_q5_1_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_q5_1_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q5_1_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q5_1_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q5_1_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q5_k_f16_f32_len;
extern const unsigned char mul_mat_vec_q5_k_f16_f32_data[];

extern const uint64_t mul_mat_vec_q5_k_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q5_k_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q5_k_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q5_k_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q5_k_f32_f32_len;
extern const unsigned char mul_mat_vec_q5_k_f32_f32_data[];

extern const uint64_t mul_mat_vec_q5_k_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q5_k_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q5_k_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q5_k_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q5_k_q8_1_f32_len;
extern const unsigned char mul_mat_vec_q5_k_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_q5_k_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q5_k_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q5_k_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q5_k_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q6_k_f16_f32_len;
extern const unsigned char mul_mat_vec_q6_k_f16_f32_data[];

extern const uint64_t mul_mat_vec_q6_k_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q6_k_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q6_k_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q6_k_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q6_k_f32_f32_len;
extern const unsigned char mul_mat_vec_q6_k_f32_f32_data[];

extern const uint64_t mul_mat_vec_q6_k_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q6_k_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q6_k_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q6_k_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q6_k_q8_1_f32_len;
extern const unsigned char mul_mat_vec_q6_k_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_q6_k_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q6_k_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q6_k_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q6_k_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q8_0_f16_f32_len;
extern const unsigned char mul_mat_vec_q8_0_f16_f32_data[];

extern const uint64_t mul_mat_vec_q8_0_f16_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q8_0_f16_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q8_0_f16_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q8_0_f16_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q8_0_f32_f32_len;
extern const unsigned char mul_mat_vec_q8_0_f32_f32_data[];

extern const uint64_t mul_mat_vec_q8_0_f32_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q8_0_f32_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q8_0_f32_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q8_0_f32_f32_subgroup_no_shmem_data[];

extern const uint64_t mul_mat_vec_q8_0_q8_1_f32_len;
extern const unsigned char mul_mat_vec_q8_0_q8_1_f32_data[];

extern const uint64_t mul_mat_vec_q8_0_q8_1_f32_subgroup_len;
extern const unsigned char mul_mat_vec_q8_0_q8_1_f32_subgroup_data[];

extern const uint64_t mul_mat_vec_q8_0_q8_1_f32_subgroup_no_shmem_len;
extern const unsigned char mul_mat_vec_q8_0_q8_1_f32_subgroup_no_shmem_data[];

extern const uint64_t multi_add_f32_len;
extern const unsigned char multi_add_f32_data[];

extern const uint64_t multi_add_rms_f32_len;
extern const unsigned char multi_add_rms_f32_data[];

extern const uint64_t neg_f16_len;
extern const unsigned char neg_f16_data[];

extern const uint64_t neg_f32_len;
extern const unsigned char neg_f32_data[];

extern const uint64_t norm_f32_len;
extern const unsigned char norm_f32_data[];

extern const uint64_t opt_step_adamw_f32_len;
extern const unsigned char opt_step_adamw_f32_data[];

extern const uint64_t opt_step_sgd_f32_len;
extern const unsigned char opt_step_sgd_f32_data[];

extern const uint64_t pad_f32_len;
extern const unsigned char pad_f32_data[];

extern const uint64_t pool2d_f32_len;
extern const unsigned char pool2d_f32_data[];

extern const uint64_t quantize_q8_1_len;
extern const unsigned char quantize_q8_1_data[];

extern const uint64_t quantize_q8_1_subgroup_len;
extern const unsigned char quantize_q8_1_subgroup_data[];

extern const uint64_t quantize_q8_1_x4_len;
extern const unsigned char quantize_q8_1_x4_data[];

extern const uint64_t quantize_q8_1_x4_subgroup_len;
extern const unsigned char quantize_q8_1_x4_subgroup_data[];

extern const uint64_t reglu_f16_len;
extern const unsigned char reglu_f16_data[];

extern const uint64_t reglu_f32_len;
extern const unsigned char reglu_f32_data[];

extern const uint64_t relu_f16_len;
extern const unsigned char relu_f16_data[];

extern const uint64_t relu_f32_len;
extern const unsigned char relu_f32_data[];

extern const uint64_t repeat_back_f32_len;
extern const unsigned char repeat_back_f32_data[];

extern const uint64_t repeat_i16_len;
extern const unsigned char repeat_i16_data[];

extern const uint64_t repeat_i32_len;
extern const unsigned char repeat_i32_data[];

extern const uint64_t rms_norm_back_f32_len;
extern const unsigned char rms_norm_back_f32_data[];

extern const uint64_t rms_norm_f32_len;
extern const unsigned char rms_norm_f32_data[];

extern const uint64_t rms_norm_mul_rope_f32_f16_len;
extern const unsigned char rms_norm_mul_rope_f32_f16_data[];

extern const uint64_t rms_norm_mul_rope_f32_f32_len;
extern const unsigned char rms_norm_mul_rope_f32_f32_data[];

extern const uint64_t rms_norm_partials_f32_len;
extern const unsigned char rms_norm_partials_f32_data[];

extern const uint64_t roll_f32_len;
extern const unsigned char roll_f32_data[];

extern const uint64_t rope_multi_f16_len;
extern const unsigned char rope_multi_f16_data[];

extern const uint64_t rope_multi_f32_len;
extern const unsigned char rope_multi_f32_data[];

extern const uint64_t rope_multi_f32_f16_len;
extern const unsigned char rope_multi_f32_f16_data[];

extern const uint64_t rope_neox_f16_len;
extern const unsigned char rope_neox_f16_data[];

extern const uint64_t rope_neox_f32_len;
extern const unsigned char rope_neox_f32_data[];

extern const uint64_t rope_neox_f32_f16_len;
extern const unsigned char rope_neox_f32_f16_data[];

extern const uint64_t rope_norm_f16_len;
extern const unsigned char rope_norm_f16_data[];

extern const uint64_t rope_norm_f32_len;
extern const unsigned char rope_norm_f32_data[];

extern const uint64_t rope_norm_f32_f16_len;
extern const unsigned char rope_norm_f32_f16_data[];

extern const uint64_t rope_vision_f16_len;
extern const unsigned char rope_vision_f16_data[];

extern const uint64_t rope_vision_f32_len;
extern const unsigned char rope_vision_f32_data[];

extern const uint64_t round_f16_len;
extern const unsigned char round_f16_data[];

extern const uint64_t round_f32_len;
extern const unsigned char round_f32_data[];

extern const uint64_t rwkv_wkv6_f32_len;
extern const unsigned char rwkv_wkv6_f32_data[];

extern const uint64_t rwkv_wkv7_f32_len;
extern const unsigned char rwkv_wkv7_f32_data[];

extern const uint64_t scale_f32_len;
extern const unsigned char scale_f32_data[];

extern const uint64_t set_rows_bf16_i32_len;
extern const unsigned char set_rows_bf16_i32_data[];

extern const uint64_t set_rows_bf16_i64_len;
extern const unsigned char set_rows_bf16_i64_data[];

extern const uint64_t set_rows_f16_i32_len;
extern const unsigned char set_rows_f16_i32_data[];

extern const uint64_t set_rows_f16_i64_len;
extern const unsigned char set_rows_f16_i64_data[];

extern const uint64_t set_rows_f32_i32_len;
extern const unsigned char set_rows_f32_i32_data[];

extern const uint64_t set_rows_f32_i64_len;
extern const unsigned char set_rows_f32_i64_data[];

extern const uint64_t set_rows_iq4_nl_i32_len;
extern const unsigned char set_rows_iq4_nl_i32_data[];

extern const uint64_t set_rows_iq4_nl_i64_len;
extern const unsigned char set_rows_iq4_nl_i64_data[];

extern const uint64_t set_rows_q1_0_i32_len;
extern const unsigned char set_rows_q1_0_i32_data[];

extern const uint64_t set_rows_q1_0_i64_len;
extern const unsigned char set_rows_q1_0_i64_data[];

extern const uint64_t set_rows_q4_0_i32_len;
extern const unsigned char set_rows_q4_0_i32_data[];

extern const uint64_t set_rows_q4_0_i64_len;
extern const unsigned char set_rows_q4_0_i64_data[];

extern const uint64_t set_rows_q4_1_i32_len;
extern const unsigned char set_rows_q4_1_i32_data[];

extern const uint64_t set_rows_q4_1_i64_len;
extern const unsigned char set_rows_q4_1_i64_data[];

extern const uint64_t set_rows_q5_0_i32_len;
extern const unsigned char set_rows_q5_0_i32_data[];

extern const uint64_t set_rows_q5_0_i64_len;
extern const unsigned char set_rows_q5_0_i64_data[];

extern const uint64_t set_rows_q5_1_i32_len;
extern const unsigned char set_rows_q5_1_i32_data[];

extern const uint64_t set_rows_q5_1_i64_len;
extern const unsigned char set_rows_q5_1_i64_data[];

extern const uint64_t set_rows_q8_0_i32_len;
extern const unsigned char set_rows_q8_0_i32_data[];

extern const uint64_t set_rows_q8_0_i64_len;
extern const unsigned char set_rows_q8_0_i64_data[];

extern const uint64_t sgn_f16_len;
extern const unsigned char sgn_f16_data[];

extern const uint64_t sgn_f32_len;
extern const unsigned char sgn_f32_data[];

extern const uint64_t sigmoid_f16_len;
extern const unsigned char sigmoid_f16_data[];

extern const uint64_t sigmoid_f32_len;
extern const unsigned char sigmoid_f32_data[];

extern const uint64_t silu_back_f32_len;
extern const unsigned char silu_back_f32_data[];

extern const uint64_t silu_f16_len;
extern const unsigned char silu_f16_data[];

extern const uint64_t silu_f32_len;
extern const unsigned char silu_f32_data[];

extern const uint64_t sin_f16_len;
extern const unsigned char sin_f16_data[];

extern const uint64_t sin_f32_len;
extern const unsigned char sin_f32_data[];

extern const uint64_t snake_bf16_len;
extern const unsigned char snake_bf16_data[];

extern const uint64_t snake_f16_len;
extern const unsigned char snake_f16_data[];

extern const uint64_t snake_f32_len;
extern const unsigned char snake_f32_data[];

extern const uint64_t soft_max_back_f32_len;
extern const unsigned char soft_max_back_f32_data[];

extern const uint64_t soft_max_f32_len;
extern const unsigned char soft_max_f32_data[];

extern const uint64_t soft_max_f32_f16_len;
extern const unsigned char soft_max_f32_f16_data[];

extern const uint64_t soft_max_large1_f32_len;
extern const unsigned char soft_max_large1_f32_data[];

extern const uint64_t soft_max_large1_f32_f16_len;
extern const unsigned char soft_max_large1_f32_f16_data[];

extern const uint64_t soft_max_large2_f32_len;
extern const unsigned char soft_max_large2_f32_data[];

extern const uint64_t soft_max_large2_f32_f16_len;
extern const unsigned char soft_max_large2_f32_f16_data[];

extern const uint64_t soft_max_large3_f32_len;
extern const unsigned char soft_max_large3_f32_data[];

extern const uint64_t soft_max_large3_f32_f16_len;
extern const unsigned char soft_max_large3_f32_f16_data[];

extern const uint64_t softplus_f16_len;
extern const unsigned char softplus_f16_data[];

extern const uint64_t softplus_f32_len;
extern const unsigned char softplus_f32_data[];

extern const uint64_t solve_tri_f32_len;
extern const unsigned char solve_tri_f32_data[];

extern const uint64_t split_k_reduce_len;
extern const unsigned char split_k_reduce_data[];

extern const uint64_t sqr_f16_len;
extern const unsigned char sqr_f16_data[];

extern const uint64_t sqr_f32_len;
extern const unsigned char sqr_f32_data[];

extern const uint64_t sqrt_f16_len;
extern const unsigned char sqrt_f16_data[];

extern const uint64_t sqrt_f32_len;
extern const unsigned char sqrt_f32_data[];

extern const uint64_t ssm_conv_f32_len;
extern const unsigned char ssm_conv_f32_data[];

extern const uint64_t ssm_scan_f32_len;
extern const unsigned char ssm_scan_f32_data[];

extern const uint64_t ssm_scan_subgroup_f32_len;
extern const unsigned char ssm_scan_subgroup_f32_data[];

extern const uint64_t step_f16_len;
extern const unsigned char step_f16_data[];

extern const uint64_t step_f32_len;
extern const unsigned char step_f32_data[];

extern const uint64_t sub_f16_f16_f16_len;
extern const unsigned char sub_f16_f16_f16_data[];

extern const uint64_t sub_f16_f16_f32_len;
extern const unsigned char sub_f16_f16_f32_data[];

extern const uint64_t sub_f16_f32_f16_len;
extern const unsigned char sub_f16_f32_f16_data[];

extern const uint64_t sub_f16_f32_f32_len;
extern const unsigned char sub_f16_f32_f32_data[];

extern const uint64_t sub_f32_len;
extern const unsigned char sub_f32_data[];

extern const uint64_t sub_f32_f16_f16_len;
extern const unsigned char sub_f32_f16_f16_data[];

extern const uint64_t sub_f32_f16_f32_len;
extern const unsigned char sub_f32_f16_f32_data[];

extern const uint64_t sub_f32_f32_f16_len;
extern const unsigned char sub_f32_f32_f16_data[];

extern const uint64_t sub_f32_f32_f32_len;
extern const unsigned char sub_f32_f32_f32_data[];

extern const uint64_t sum_rows_f32_len;
extern const unsigned char sum_rows_f32_data[];

extern const uint64_t swiglu_f16_len;
extern const unsigned char swiglu_f16_data[];

extern const uint64_t swiglu_f32_len;
extern const unsigned char swiglu_f32_data[];

extern const uint64_t swiglu_oai_f16_len;
extern const unsigned char swiglu_oai_f16_data[];

extern const uint64_t swiglu_oai_f32_len;
extern const unsigned char swiglu_oai_f32_data[];

extern const uint64_t tanh_f16_len;
extern const unsigned char tanh_f16_data[];

extern const uint64_t tanh_f32_len;
extern const unsigned char tanh_f32_data[];

extern const uint64_t timestep_embedding_f32_len;
extern const unsigned char timestep_embedding_f32_data[];

extern const uint64_t topk_argsort_f32_len;
extern const unsigned char topk_argsort_f32_data[];

extern const uint64_t topk_moe_f32_len;
extern const unsigned char topk_moe_f32_data[];

extern const uint64_t topk_nary_search_f32_len;
extern const unsigned char topk_nary_search_f32_data[];

extern const uint64_t tri_f16_len;
extern const unsigned char tri_f16_data[];

extern const uint64_t tri_f32_len;
extern const unsigned char tri_f32_data[];

extern const uint64_t trunc_f16_len;
extern const unsigned char trunc_f16_data[];

extern const uint64_t trunc_f32_len;
extern const unsigned char trunc_f32_data[];

extern const uint64_t upscale_f32_len;
extern const unsigned char upscale_f32_data[];

extern const uint64_t xielu_f16_len;
extern const unsigned char xielu_f16_data[];

extern const uint64_t xielu_f32_len;
extern const unsigned char xielu_f32_data[];

extern const void * add_data[2][2][2];
extern const uint64_t add_len[2][2][2];
extern const void * sub_data[2][2][2];
extern const uint64_t sub_len[2][2][2];
extern const void * mul_data[2][2][2];
extern const uint64_t mul_len[2][2][2];
extern const void * div_data[2][2][2];
extern const uint64_t div_len[2][2][2];
extern const void * add_rms_data[2][2][2];
extern const uint64_t add_rms_len[2][2][2];
extern const void * arr_dmmv_f32_f16_f32_data[3];
extern const uint64_t arr_dmmv_f32_f16_f32_len[3];
extern const void * arr_dmmv_f16_f16_f32_data[3];
extern const uint64_t arr_dmmv_f16_f16_f32_len[3];
extern const void * arr_dmmv_q1_0_f16_f32_data[3];
extern const uint64_t arr_dmmv_q1_0_f16_f32_len[3];
extern const void * arr_dmmv_q4_0_f16_f32_data[3];
extern const uint64_t arr_dmmv_q4_0_f16_f32_len[3];
extern const void * arr_dmmv_q4_1_f16_f32_data[3];
extern const uint64_t arr_dmmv_q4_1_f16_f32_len[3];
extern const void * arr_dmmv_q5_0_f16_f32_data[3];
extern const uint64_t arr_dmmv_q5_0_f16_f32_len[3];
extern const void * arr_dmmv_q5_1_f16_f32_data[3];
extern const uint64_t arr_dmmv_q5_1_f16_f32_len[3];
extern const void * arr_dmmv_q8_0_f16_f32_data[3];
extern const uint64_t arr_dmmv_q8_0_f16_f32_len[3];
extern const void * arr_dmmv_q2_k_f16_f32_data[3];
extern const uint64_t arr_dmmv_q2_k_f16_f32_len[3];
extern const void * arr_dmmv_q3_k_f16_f32_data[3];
extern const uint64_t arr_dmmv_q3_k_f16_f32_len[3];
extern const void * arr_dmmv_q4_k_f16_f32_data[3];
extern const uint64_t arr_dmmv_q4_k_f16_f32_len[3];
extern const void * arr_dmmv_q5_k_f16_f32_data[3];
extern const uint64_t arr_dmmv_q5_k_f16_f32_len[3];
extern const void * arr_dmmv_q6_k_f16_f32_data[3];
extern const uint64_t arr_dmmv_q6_k_f16_f32_len[3];
extern const void * arr_dmmv_iq1_s_f16_f32_data[3];
extern const uint64_t arr_dmmv_iq1_s_f16_f32_len[3];
extern const void * arr_dmmv_iq1_m_f16_f32_data[3];
extern const uint64_t arr_dmmv_iq1_m_f16_f32_len[3];
extern const void * arr_dmmv_iq2_xxs_f16_f32_data[3];
extern const uint64_t arr_dmmv_iq2_xxs_f16_f32_len[3];
extern const void * arr_dmmv_iq2_xs_f16_f32_data[3];
extern const uint64_t arr_dmmv_iq2_xs_f16_f32_len[3];
extern const void * arr_dmmv_iq2_s_f16_f32_data[3];
extern const uint64_t arr_dmmv_iq2_s_f16_f32_len[3];
extern const void * arr_dmmv_iq3_xxs_f16_f32_data[3];
extern const uint64_t arr_dmmv_iq3_xxs_f16_f32_len[3];
extern const void * arr_dmmv_iq3_s_f16_f32_data[3];
extern const uint64_t arr_dmmv_iq3_s_f16_f32_len[3];
extern const void * arr_dmmv_iq4_xs_f16_f32_data[3];
extern const uint64_t arr_dmmv_iq4_xs_f16_f32_len[3];
extern const void * arr_dmmv_iq4_nl_f16_f32_data[3];
extern const uint64_t arr_dmmv_iq4_nl_f16_f32_len[3];
extern const void * arr_dmmv_mxfp4_f16_f32_data[3];
extern const uint64_t arr_dmmv_mxfp4_f16_f32_len[3];
extern const void * arr_dmmv_nvfp4_f16_f32_data[3];
extern const uint64_t arr_dmmv_nvfp4_f16_f32_len[3];
extern const void * arr_dmmv_bf16_f16_f32_data[3];
extern const uint64_t arr_dmmv_bf16_f16_f32_len[3];
extern const void * arr_dmmv_f32_f32_f32_data[3];
extern const uint64_t arr_dmmv_f32_f32_f32_len[3];
extern const void * arr_dmmv_id_f32_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_f32_f32_f32_len[3];
extern const void * arr_dmmv_f16_f32_f32_data[3];
extern const uint64_t arr_dmmv_f16_f32_f32_len[3];
extern const void * arr_dmmv_id_f16_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_f16_f32_f32_len[3];
extern const void * arr_dmmv_q1_0_f32_f32_data[3];
extern const uint64_t arr_dmmv_q1_0_f32_f32_len[3];
extern const void * arr_dmmv_id_q1_0_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_q1_0_f32_f32_len[3];
extern const void * arr_dmmv_q4_0_f32_f32_data[3];
extern const uint64_t arr_dmmv_q4_0_f32_f32_len[3];
extern const void * arr_dmmv_id_q4_0_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_q4_0_f32_f32_len[3];
extern const void * arr_dmmv_q4_1_f32_f32_data[3];
extern const uint64_t arr_dmmv_q4_1_f32_f32_len[3];
extern const void * arr_dmmv_id_q4_1_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_q4_1_f32_f32_len[3];
extern const void * arr_dmmv_q5_0_f32_f32_data[3];
extern const uint64_t arr_dmmv_q5_0_f32_f32_len[3];
extern const void * arr_dmmv_id_q5_0_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_q5_0_f32_f32_len[3];
extern const void * arr_dmmv_q5_1_f32_f32_data[3];
extern const uint64_t arr_dmmv_q5_1_f32_f32_len[3];
extern const void * arr_dmmv_id_q5_1_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_q5_1_f32_f32_len[3];
extern const void * arr_dmmv_q8_0_f32_f32_data[3];
extern const uint64_t arr_dmmv_q8_0_f32_f32_len[3];
extern const void * arr_dmmv_id_q8_0_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_q8_0_f32_f32_len[3];
extern const void * arr_dmmv_q2_k_f32_f32_data[3];
extern const uint64_t arr_dmmv_q2_k_f32_f32_len[3];
extern const void * arr_dmmv_id_q2_k_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_q2_k_f32_f32_len[3];
extern const void * arr_dmmv_q3_k_f32_f32_data[3];
extern const uint64_t arr_dmmv_q3_k_f32_f32_len[3];
extern const void * arr_dmmv_id_q3_k_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_q3_k_f32_f32_len[3];
extern const void * arr_dmmv_q4_k_f32_f32_data[3];
extern const uint64_t arr_dmmv_q4_k_f32_f32_len[3];
extern const void * arr_dmmv_id_q4_k_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_q4_k_f32_f32_len[3];
extern const void * arr_dmmv_q5_k_f32_f32_data[3];
extern const uint64_t arr_dmmv_q5_k_f32_f32_len[3];
extern const void * arr_dmmv_id_q5_k_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_q5_k_f32_f32_len[3];
extern const void * arr_dmmv_q6_k_f32_f32_data[3];
extern const uint64_t arr_dmmv_q6_k_f32_f32_len[3];
extern const void * arr_dmmv_id_q6_k_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_q6_k_f32_f32_len[3];
extern const void * arr_dmmv_iq1_s_f32_f32_data[3];
extern const uint64_t arr_dmmv_iq1_s_f32_f32_len[3];
extern const void * arr_dmmv_id_iq1_s_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_iq1_s_f32_f32_len[3];
extern const void * arr_dmmv_iq1_m_f32_f32_data[3];
extern const uint64_t arr_dmmv_iq1_m_f32_f32_len[3];
extern const void * arr_dmmv_id_iq1_m_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_iq1_m_f32_f32_len[3];
extern const void * arr_dmmv_iq2_xxs_f32_f32_data[3];
extern const uint64_t arr_dmmv_iq2_xxs_f32_f32_len[3];
extern const void * arr_dmmv_id_iq2_xxs_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_iq2_xxs_f32_f32_len[3];
extern const void * arr_dmmv_iq2_xs_f32_f32_data[3];
extern const uint64_t arr_dmmv_iq2_xs_f32_f32_len[3];
extern const void * arr_dmmv_id_iq2_xs_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_iq2_xs_f32_f32_len[3];
extern const void * arr_dmmv_iq2_s_f32_f32_data[3];
extern const uint64_t arr_dmmv_iq2_s_f32_f32_len[3];
extern const void * arr_dmmv_id_iq2_s_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_iq2_s_f32_f32_len[3];
extern const void * arr_dmmv_iq3_xxs_f32_f32_data[3];
extern const uint64_t arr_dmmv_iq3_xxs_f32_f32_len[3];
extern const void * arr_dmmv_id_iq3_xxs_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_iq3_xxs_f32_f32_len[3];
extern const void * arr_dmmv_iq3_s_f32_f32_data[3];
extern const uint64_t arr_dmmv_iq3_s_f32_f32_len[3];
extern const void * arr_dmmv_id_iq3_s_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_iq3_s_f32_f32_len[3];
extern const void * arr_dmmv_iq4_xs_f32_f32_data[3];
extern const uint64_t arr_dmmv_iq4_xs_f32_f32_len[3];
extern const void * arr_dmmv_id_iq4_xs_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_iq4_xs_f32_f32_len[3];
extern const void * arr_dmmv_iq4_nl_f32_f32_data[3];
extern const uint64_t arr_dmmv_iq4_nl_f32_f32_len[3];
extern const void * arr_dmmv_id_iq4_nl_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_iq4_nl_f32_f32_len[3];
extern const void * arr_dmmv_mxfp4_f32_f32_data[3];
extern const uint64_t arr_dmmv_mxfp4_f32_f32_len[3];
extern const void * arr_dmmv_id_mxfp4_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_mxfp4_f32_f32_len[3];
extern const void * arr_dmmv_nvfp4_f32_f32_data[3];
extern const uint64_t arr_dmmv_nvfp4_f32_f32_len[3];
extern const void * arr_dmmv_id_nvfp4_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_nvfp4_f32_f32_len[3];
extern const void * arr_dmmv_bf16_f32_f32_data[3];
extern const uint64_t arr_dmmv_bf16_f32_f32_len[3];
extern const void * arr_dmmv_id_bf16_f32_f32_data[3];
extern const uint64_t arr_dmmv_id_bf16_f32_f32_len[3];
extern const void * arr_dmmv_q4_0_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_q4_0_q8_1_f32_len[3];
extern const void * arr_dmmv_id_q4_0_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_id_q4_0_q8_1_f32_len[3];
extern const void * arr_dmmv_q4_1_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_q4_1_q8_1_f32_len[3];
extern const void * arr_dmmv_id_q4_1_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_id_q4_1_q8_1_f32_len[3];
extern const void * arr_dmmv_q5_0_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_q5_0_q8_1_f32_len[3];
extern const void * arr_dmmv_id_q5_0_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_id_q5_0_q8_1_f32_len[3];
extern const void * arr_dmmv_q5_1_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_q5_1_q8_1_f32_len[3];
extern const void * arr_dmmv_id_q5_1_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_id_q5_1_q8_1_f32_len[3];
extern const void * arr_dmmv_q8_0_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_q8_0_q8_1_f32_len[3];
extern const void * arr_dmmv_id_q8_0_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_id_q8_0_q8_1_f32_len[3];
extern const void * arr_dmmv_q2_k_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_q2_k_q8_1_f32_len[3];
extern const void * arr_dmmv_id_q2_k_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_id_q2_k_q8_1_f32_len[3];
extern const void * arr_dmmv_q3_k_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_q3_k_q8_1_f32_len[3];
extern const void * arr_dmmv_id_q3_k_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_id_q3_k_q8_1_f32_len[3];
extern const void * arr_dmmv_q4_k_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_q4_k_q8_1_f32_len[3];
extern const void * arr_dmmv_id_q4_k_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_id_q4_k_q8_1_f32_len[3];
extern const void * arr_dmmv_q5_k_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_q5_k_q8_1_f32_len[3];
extern const void * arr_dmmv_id_q5_k_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_id_q5_k_q8_1_f32_len[3];
extern const void * arr_dmmv_q6_k_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_q6_k_q8_1_f32_len[3];
extern const void * arr_dmmv_id_q6_k_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_id_q6_k_q8_1_f32_len[3];
extern const void * arr_dmmv_iq1_s_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_iq1_s_q8_1_f32_len[3];
extern const void * arr_dmmv_id_iq1_s_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_id_iq1_s_q8_1_f32_len[3];
extern const void * arr_dmmv_iq1_m_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_iq1_m_q8_1_f32_len[3];
extern const void * arr_dmmv_id_iq1_m_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_id_iq1_m_q8_1_f32_len[3];
extern const void * arr_dmmv_mxfp4_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_mxfp4_q8_1_f32_len[3];
extern const void * arr_dmmv_id_mxfp4_q8_1_f32_data[3];
extern const uint64_t arr_dmmv_id_mxfp4_q8_1_f32_len[3];
